      subroutine XSQY_BRO(nw,wl,wc,nz,tlev,airlev,j,sq,jlabel,pn)

!-----------------------------------------------------------------------------!
!   purpose:                                                                  !
!   provide product (cross section) x (quantum yield):                        !
!           bro + hv -> br + o                                                !
!   cross section: JPL06 (5nm Cox average)                                    !
!   quantum yield: is unity.                                                  !
!-----------------------------------------------------------------------------!
!   parameters:                                                               !
!   nw     - integer, number of specified intervals + 1 in working        (i) !
!            wavelength grid                                                  !
!   wl     - real, vector of lower limits of wavelength intervals in      (i) !
!            working wavelength grid                                          !
!   wc     - real, vector of center points of wavelength intervals in     (i) !
!            working wavelength grid                                          !
!   nz     - integer, number of altitude levels in working altitude grid  (i) !
!   tlev   - real, temperature (k) at each specified altitude level       (i) !
!   airlev - real, air density (molec/cc) at each altitude level          (i) !
!   j      - integer, counter for number of weighting functions defined  (io) !
!   sq     - real, cross section x quantum yield (cm^2) for each          (o) !
!            photolysis reaction defined, at each defined wavelength and      !
!            at each defined altitude level                                   !
!   jlabel - character*60, string identifier for each photolysis reaction (o) !
!            defined                                                          !
!-----------------------------------------------------------------------------!
!   edit history:                                                             !
!   07/27/07  Doug Kinnison                                                   !
!-----------------------------------------------------------------------------!
      implicit none
      include 'params'

!-----------------------------------------------------------------------------!
!     ... input                                                               !
!-----------------------------------------------------------------------------!
      real, intent(in) :: wl(kw)
      real, intent(in) :: wc(kw)
      real, intent(in) :: tlev(kz)
      real, intent(in) :: airlev(kz)

      integer, intent(in) :: nz
      integer, intent(in) :: nw

      character*80, intent(in)  ::  pn
      character*60, intent(out) :: jlabel(kj)
      real, intent(out)         :: sq(kj,kz,kw)

!-----------------------------------------------------------------------------!
!     ... input/output                                                        !
!-----------------------------------------------------------------------------!
      integer, intent(inout) :: j

!-----------------------------------------------------------------------------!
!     ... local                                                               !
!-----------------------------------------------------------------------------!
      integer kdata
      parameter(kdata=200)
      real x1(kdata)
      real x2(kdata)
      real x3(kdata)
      real y1(kdata)
      real yg(kw)
      real yg1(kw)
      real qy
      integer i, iw, n, idum
      integer ierr
      integer iz

!----------------------------------------------
!     ... jlabel(j) = 'bro -> br + o'
!----------------------------------------------
      j = j+1
      jlabel(j) = 'bro + hv -> br + o'

!----------------------------------------------------
!     ... cross sections from JPL06 recommendation
!----------------------------------------------------
      open(kin,file=TRIM(pn)//'XS_BRO_Cox_5nm_JPL06.txt',status='old')
      read(kin,*) idum, n
      do i = 1, idum-2
        read(kin,*)
      enddo

!     ... cross sections are 5nm average values
!     ... scaled to total area per bin; use inter3
      do i = 1, n
        read(kin,*) x1(i), x3(i), y1(i)
        y1(i) = (x3(i)-x1(i))* y1(i) * 1e-20
      enddo
      close(kin)

      x1(n+1) = x3(n)   
      n       = n+1

      call inter3(nw,wl,yg1,n,x1,y1,0)

!     ...yg1 is per nm, so rescale by bin widths

      do iw = 1, nw-1
         yg(iw) = yg1(iw)/(wl(iw+1)-wl(iw))
      enddo
      
!-------------------------------------------------------
!     ... quantum yield (assumed) to be unity (JPL06)
!-------------------------------------------------------
      qy = 1.0

      do iw = 1, nw-1
        do iz = 1, nz
          sq(j,iz,iw) = qy * yg(iw)
        enddo
      enddo

!-------------------------------------------------------
!     ... Check routine (no temperature dependence)
!      do iw = 1, nw-1
!        print*, iw, wc(iw), (qy * yg(iw))
!      enddo
!-------------------------------------------------------

      end subroutine XSQY_BRO
