      subroutine XSQY_O3(nw,wl,wc,nz,tlev,airlev,j,sq,jlabel,pn)
!-----------------------------------------------------------------------------!
!   purpose:                                                                  !
!   provide the product of (cross section) x (quantum yield) for the two      !
!   o3 photolysis reactions:                                                  !
!              (a) o3 + hv -> o2 + o(1d)                                      !
!              (b) o3 + hv -> o2 + o(3p)                                      !
!   cross sections:                                                           !
!               120nm - 185 nm = Ackerman, 1971                               !
!               185nm - 827 nm = JPL06 (293-298K)                             !
!               196nm - 342 nm = JPL06 (218 K)                                !
!   quantum yield:  jpl 06 recommendation                                     !
!-----------------------------------------------------------------------------!
!   parameters:                                                               !
!   nw     - integer, number of specified intervals + 1 in working        (i) !
!            wavelength grid                                                  !
!   wl     - real, vector of lower limits of wavelength intervals in      (i) !
!            working wavelength grid                                          !
!   wc     - real, vector of center points of wavelength intervals in     (i) !
!            working wavelength grid                                          !
!   nz     - integer, number of altitude levels in working altitude grid  (i) !
!   tlev   - real, temperature (k) at each specified altitude level       (i) !
!   airlev - real, air density (molec/cc) at each altitude level          (i) !
!   j      - integer, counter for number of weighting functions defined  (io) !
!   sq     - real, cross section x quantum yield (cm^2) for each          (o) !
!            photolysis reaction defined, at each defined wavelength and      !
!            at each defined altitude level                                   !
!   jlabel - character*60, string identifier for each photolysis reaction (o) !
!            defined                                                          !
!-----------------------------------------------------------------------------!
!   edit history:                                                             !
!   02/06/08  JPL-06 Doug Kinnison                                            !
!   01/02  Atkinson, 1971, 120-175nm, Doug Kinnison                           !
!-----------------------------------------------------------------------------!
      implicit none

      include 'params'
!-----------------------------------------------------------------------------!
!     ... input                                                               !
!-----------------------------------------------------------------------------!
      real, intent(in) :: wl(kw)
      real, intent(in) :: wc(kw)
      real, intent(in) :: tlev(kz)
      real, intent(in) :: airlev(kz)

      integer, intent(in) :: nz
      integer, intent(in) :: nw
      
      character*80 pn

      character*60, intent(out) :: jlabel(kj)
      real, intent(out) :: sq(kj,kz,kw)

!     ... input/output:
      integer, j

!-----------------------------------------------------------------------------!
!     ... Local arrays                                                        !
!-----------------------------------------------------------------------------!

      integer, parameter :: kdata = 250
      integer n1, n2, n3, iskip, ierr
      integer i, iw, iz, n, idum, kk
      real x1(kdata), x2(kdata), x3(kdata), x4(kdata), x5(13)
      real y1(kdata), y2(kdata), y3(kdata), y4(kdata), y5(13)
      real yg(kw), yg298(kw), yg218(kw),qy_marsh(kw)
      real xso3(kw),s226(kw),s263(kw),s298(kw)
      real qy3p(kz,kw)
      real a1, a2, a3
      real so3(kz,kw)
      real tin(kz)
      real dum
      real w, t, kt
      real A(3), X(3), om(3)
      real q1, q2, QY_O1D(nz,kw)


      real qy1d(kz,kw)
      real x01, x02, x03
      real k, v2, v3
      real w1, w2, w3

      DATA A/ 0.8036, 8.9061, 0.1192/
      DATA X/ 304.225, 314.957, 310.737/
      DATA om/ 5.576, 6.601, 2.187/

!-----------------------------------------------------------
!     ... tin set to tlev
!-----------------------------------------------------------
      tin(:) = tlev(:)

!-----------------------------------------------------------
!     ... jlabel(j) = 'O3 -> O2 + O(1D)'
!     ... jlabel(j) = 'O3 -> O2 + O(3P)'
!-----------------------------------------------------------
      j = j + 1
      jlabel(j) = 'O3 -> O2 + O(1D)'
      
      j = j + 1
      jlabel(j) = 'O3 -> O2 + O(3P)'

!-----------------------------------------------------------
!     Ref: Atkinson, ultraviolet solar radiation related to 
!          mesopheric procesess, 149-159, in fiocco, g. (ed.), 
!          mesospheric models and related exp., d. reidel, 
!          dordrecht, 1971. 
!          120 nm through 200 nm
!-----------------------------------------------------------
      open(unit=kin,file=TRIM(pn)//'XS_O3_Ackerman_1971.txt',
     $     status='old')
      read(kin,*) iskip, n
      do i = 1, iskip
        read(kin,*) 
      end do
      do i = 1, n
        read(kin,*) x1(i), y1(i)
      enddo
      close(kin)

      call addpnt(x1,y1,kdata,n,x1(1)*(1.-deltax),0.)
      call addpnt(x1,y1,kdata,n,               0.,0.)
      call addpnt(x1,y1,kdata,n,x1(n)*(1.+deltax),0.)
      call addpnt(x1,y1,kdata,n,           1.e+38,0.)
      call inter2(nw,wl,yg,n,x1,y1,ierr)
      if (ierr .ne. 0) then
         write(*,*) ierr, jlabel(j)
         stop
      endif

      do iw = 1, nw-1
         xso3(iw) = yg(iw)
      enddo
!-------------------------------------------------------
!     ... Check routine 
!      do iw = 1,36
!        print*, iw, wc(iw), yg(iw)
!      enddo
!      stop
!-------------------------------------------------------
!-------------------------------------------------------
!     ... REF: JPL06 218K
!         from 196.078 to 342.5 nm
!-------------------------------------------------------
      open(unit=kin,file=TRIM(pn)//'XS_O3_218_JPL06.txt',
     $     status='old')
      read(kin,*) iskip, n
      do i = 1, iskip
        read(kin,*) 
      end do
      do i = 1, n
        read(kin,*) a1, a2, y2(i)
        x2(i) = (a1+a2)/2.
!        print*, x2(i), y2(i)
      enddo
      close(kin)

      call addpnt(x2,y2,kdata,n,x2(1)*(1.-deltax),0.)
      call addpnt(x2,y2,kdata,n,               0.,0.)
      call addpnt(x2,y2,kdata,n,x2(n)*(1.+deltax),0.)
      call addpnt(x2,y2,kdata,n,           1.e+38,0.)
      call inter2(nw,wl,yg218,n,x2,y2,ierr)
      if (ierr .ne. 0) then
         write(*,*) ierr, jlabel(j)
         stop
      endif
!-------------------------------------------------------
!     ... Check routine 
!      do iw = 1,nw-1
!        print*, iw, wc(iw), yg218(iw)
!      enddo
!      stop
!-------------------------------------------------------
!-------------------------------------------------------
!     ... REF: JPL06 293-298K
!         from 185.185 to 827.500 nm
!-------------------------------------------------------
      open(unit=kin,file=TRIM(pn)//'XS_O3_298_JPL06.txt',
     $     status='old')
      read(kin,*) iskip, n
      do i = 1, iskip
        read(kin,*) 
      end do
      do i = 1, n
        read(kin,*) a1, a2, y3(i)
        x3(i) = (a1+a2)/2.
      enddo
      close(kin)

      call addpnt(x3,y3,kdata,n,x3(1)*(1.-deltax),0.)
      call addpnt(x3,y3,kdata,n,               0.,0.)
      call addpnt(x3,y3,kdata,n,x3(n)*(1.+deltax),0.)
      call addpnt(x3,y3,kdata,n,           1.e+38,0.)
      call inter2(nw,wl,yg298,n,x3,y3,ierr)
      if (ierr .ne. 0) then
         write(*,*) ierr, jlabel(j)
         stop
      endif
!-------------------------------------------------------
!     ... Check routine 
!      do iw = 1,nw-1
!      print*, iw, wc(iw), yg298(iw)
!      enddo
!      stop
!-------------------------------------------------------
      do iw = 1, nw-1
	if (wc(iw) .ge. 184.0) then
           xso3(iw) = yg298(iw)
	endif
      enddo
!-------------------------------------------------------
!     ... Check routine 
!      do iw = 1,nw-1
!        print*, iw, wc(iw), xso3(iw)
!      enddo
!      stop
!-------------------------------------------------------
!-------------------------------------------------------
!     ... for hartley and huggins bands, use 
!         temperature-dependent values from
!         JPL06
!-------------------------------------------------------
!-------------------------------------------------------
!     ... Cross Sections and Quantum Yields
!-------------------------------------------------------
      do iw = 1, nw-1
         do iz = 1, nz

         so3(iz,iw) = xso3(iw)

           if ((wc(iw) .ge. 196.078) .and. (wc(iw) .le. 342.5)) then

             if (tin(iz) .lt. 218.) then
               so3(iz,iw) = yg218(iw)
             endif
             if ((tin(iz) .ge. 218.) .and. (tin(iz) .le. 298.)) then
               so3(iz,iw) = yg218(iw)+(yg298(iw)-yg218(iw))/(298.-218.)*
     $                 (tin(iz)-218.)
             endif
             if (tin(iz) .gt. 298.) then
               so3(iz,iw) = yg298(iw)
             endif
           endif

          enddo
       enddo

!------------------------------------------------------
!     ... Check routine 
!      iz = 1
!      print*, "tin=", tin(iz)
!      do iw = 26,78
!        print*, iw, wc(iw), so3(iz,iw)
!      enddo
!      stop
!-----------------------------------------------------------
!     ... Impose qy from marsh (thesis 1999) - for 
!         mesospheric production
!-----------------------------------------------------------
 
!     ... wavelengths (nm) consistent with qy
           data x5 /157.6, 193.0, 221.5, 222.0, 228.5, 
     $              231.0, 235.0, 243.5, 248.0, 253.7,
     $              266.0, 274.0, 280.0/

!     ... qy taken from several sources (see marsh)
           data y5 /0.29, 0.46, 0.87, 0.87, 0.83, 
     $              0.83, 0.88, 0.88, 0.91, 0.92,
     $              0.88, 0.90, 0.92/
	do kk = 1, 13
	  x1(kk) = x5(kk)
	  y1(kk) = y5(kk)
      enddo
      n = 13 
      call addpnt(x1,y1,kdata,n,120.0,0.3)
      call addpnt(x1,y1,kdata,n,          0.,0.)
      call addpnt(x1,y1,kdata,n,x1(n)*(1.+deltax),0.95)
      call addpnt(x1,y1,kdata,n,        1e38,0.)

      call inter2(nw,wl,qy_marsh,n,x1,y1,ierr)

!-----------------------------------------------------------
!     ... Cross Sections and Quantum Yields
!-----------------------------------------------------------
      do iw = 1, nw-1

         do i = 1, nz

!     ... from jpl '00 (created by doug kinnison, 6/8/01)
             k  = 0.695		!  units cm-1 k

!     ... coefficients taken from table 4, jpl00, page 33

             a1  = 0.887
	     a2  = 2.35
	     a3  = 57.
             x01 = 302.
	     x02 = 311.1
             x03 = 313.9
              v2 = 820.
	      v3 = 1190.
              w1 = 7.9
	      w2 = 2.2
	      w3 = 7.4
			
!     ... equation for qy taken from jpl00, page 32.
             t = max( 200., tlev(i))
             t = min( 300., tlev(i) )

             if( wc(iw) .lt. 300. ) then
               qy1d(i,iw) = qy_marsh(iw) !not temperature dependent
             else if ( wc(iw) .gt. 330. .and. wc(iw) .le. 345 ) then
               qy1d(i,iw) = 0.06
             else if ( wc(iw) .gt. 345.) then
               qy1d(i,iw) = 0.0
             else if (wc(iw) .le. 330 .and. wc(iw) .ge. 300. ) then
            
                qy1d(i,iw) =   a1 * exp(-((wc(iw)-x01)/w1)**4)
     $                + a2 * (t/300)**4 * exp(-v2/(k*t))
     $                     * exp(-((wc(iw)-x02)/w2)**2)
     $                + a3 * exp(-v3/(k*t))
     $                     * exp(-((wc(iw)-x03)/w3)**2) 
     $                + 0.06

   	         qy1d(i,iw) = min(qy1d(i,iw),1.0)
	       
             endif

           qy1d(i,iw) = min(qy1d(i,iw),1.0)

!-----------------------------------------------------------
!     ... derive the cross section*qy
!-----------------------------------------------------------
           sq(j-1,i,iw) = qy1d(i,iw)*so3(i,iw)
           qy3p(i,iw)   = 1.0 - qy1d(i,iw)
           sq(j,i,iw)   = qy3p(i,iw)*so3(i,iw)
   
         enddo
      enddo
!------------------------------------------------------ 
!     ... Check routine 
      i = 100
      print*,"tlev=", tlev(i)
      do iw = 1,78
        print*, iw, wc(iw), qy1d(i,iw), qy3p(i,iw), so3(i,iw)
      enddo
      
!------------------------------------------------------ 
      end subroutine XSQY_O3
