      subroutine XSQY_BRCL(nw,wl,wc,nz,tlev,airlev,j,sq,jlabel,pn)
!-----------------------------------------------------------------------------!
!   purpose:                                                                  !
!   provide product (cross section) x (quantum yield) for hcl photolysis:     !
!           BrCl + hv -> Br + Cl                                              !
!                                                                             !
!   cross section: from JPL-06                                                !
!                                                                             !
!   quantum yield: assumed to be 1.0                                          !
!-----------------------------------------------------------------------------!
!   parameters:                                                               !
!   nw     - integer, number of specified intervals + 1 in working        (i) !
!            wavelength grid                                                  !
!   wl     - real, vector of lower limits of wavelength intervals in      (i) !
!            working wavelength grid                                          !
!   wc     - real, vector of center points of wavelength intervals in     (i) !
!            working wavelength grid                                          !
!   nz     - integer, number of altitude levels in working altitude grid  (i) !
!   tlev   - real, temperature (k) at each specified altitude level       (i) !
!   airlev - real, air density (molec/cc) at each altitude level          (i) !
!   j      - integer, counter for number of weighting functions defined  (io) !
!   sq     - real, cross section x quantum yield (cm^2) for each          (o) !
!            photolysis reaction defined, at each defined wavelength and      !
!            at each defined altitude level                                   !
!   jlabel - character*60, string identifier for each photolysis reaction (o) !
!            defined                                                          !
!-----------------------------------------------------------------------------!
!   edit history:                                                             !
!   06/06/01   original, dek addition                                         !
!-----------------------------------------------------------------------------!
      implicit none
      include 'params'

!-----------------------------------------------------------------------------!
!     ... input                                                               !
!-----------------------------------------------------------------------------!
      real, intent(in) :: wl(kw)
      real, intent(in) :: wc(kw)
      real, intent(in) :: tlev(kz)
      real, intent(in) :: airlev(kz)

      integer, intent(in) :: nz
      integer, intent(in) :: nw

      character*80, intent(in) ::  pn
      character*60, intent(out) :: jlabel(kj)
      real, intent(out) :: sq(kj,kz,kw)

!-----------------------------------------------------------------------------!
!     ... input/output                                                        !
!-----------------------------------------------------------------------------!
      integer, intent(inout) :: j

!-----------------------------------------------------------------------------!
!     ... local                                                               !
!-----------------------------------------------------------------------------!
      integer kdata
      parameter(kdata=200)
      integer i, iw, n, idum, ierr, iz
      real x1(kdata)
      real y1(kdata)
      real yg(kw)
      real qy, alpha, e1, e2, e3, c0, c1, c2, c3, tin, tin1

!----------------------------------------------
!     ... jlabel(j) = 'BrCl + hv -> Br + Cl'
!----------------------------------------------
      j = j+1
      jlabel(j) = 'BrCl + hv -> Br + Cl'

!----------------------------------------------------
!     ... cross sections from JPL06 recommendation
!----------------------------------------------------
!     note: the equation programed below does not correctly represent
!           table 56, page 200, jpl96-4. e.g., at 298k and 200nm the
!           cross section is 2.64x10^-20 versus table 56 value of 2.4x10^-20.
!           temperature range is: 300 k >= t  >= 195 k
!           wavelength range is:  200nm <= wl <= 600nm
!----------------------------------------------------------------------------
!     ...quantum yield is (assumed) to be unity. was not discussed in JPL06.
!----------------------------------------------------------------------------
      do iz = 1, nz
        do iw = 1, nw-1
          
	    if (wc(iw) .ge. 200.0 .and. wc(iw) .le. 600.0) then
	     
	      tin   = min(tlev(iz),300.0)
	      tin1  = max(tin,195.0)

              alpha = tanh (318.8/tin1)
              e1    = -68.6 *(alpha*(log (227.6/wc(iw)) )**2)
	      e2    = -123.6*(alpha*(log (372.5/wc(iw)) )**2)
	      e3    = -84.8 *(alpha*(log (442.4/wc(iw)) )**2)
 
	      c0    = (alpha**0.5)
	      c1    = 7.34
	      c2    = 43.5
	      c3    = 11.2
	      qy    = 1.0
	
	      yg(iw)= c0*(c1*exp(e1) + c2*exp(e2) +  c3*exp(e3))

	      sq(j,iz,iw) = qy * yg(iw)* 1.0e-20

	    endif
	  enddo
	enddo
!-------------------------------------------------------
!     ... Check routine
!      iz = 1
!      do iw = 1,100
!        print*, iw, wc(iw), sq(j,iz,iw),tlev(iz)
!      enddo
!      stop
!-------------------------------------------------------
      
      end subroutine XSQY_BRCL
