      subroutine XSQY_CH2O(nw,wl,wc,nz,tlev,airlev,j,sq,jlabel,pn)
!-----------------------------------------------------------------------------!
!   purpose:                                                                  !
!   provide product of (cross section) x (quantum yield) for ch2o photolysis  !
!         (a) ch2o + hv -> h + hco                                            !
!         (b) ch2o + hv -> h2 + co                                            !
!   cross section: choice between                                             !
!                  1) bass et al., 1980 (resolution: 0.025 nm)                !
!                  2) moortgat and schneider (resolution: 1 nm)               !
!                  3) cantrell et al. (orig res.) for > 301 nm,               !
!                     iupac 92, 97 elsewhere                                  !
!                  4) cantrell et al. (2.5 nm res.) for > 301 nm,             !
!                     iupac 92, 97 elsewhere                                  !
!                  5) rogers et al., 1990                                     !
!                  6) new ncar recommendation, based on averages of           !
!                     cantrell et al., moortgat and schneider, and rogers     !
!                     et al.                                                  !
!   quantum yield: choice between                                             !
!                  1) evaluation by madronich 1991 (unpublished)              !
!                  2) iupac 89, 92, 97                                        !
!                  3) madronich, based on 1), updated 1998.                   !
!-----------------------------------------------------------------------------!
!   parameters:                                                               !
!   nw     - integer, number of specified intervals + 1 in working        (i) !
!            wavelength grid                                                  !
!   wl     - real, vector of lower limits of wavelength intervals in      (i) !
!            working wavelength grid                                          !
!   wc     - real, vector of center points of wavelength intervals in     (i) !
!            working wavelength grid                                          !
!   nz     - integer, number of altitude levels in working altitude grid  (i) !
!   tlev   - real, temperature (k) at each specified altitude level       (i) !
!   airlev - real, air density (molec/cc) at each altitude level          (i) !
!   j      - integer, counter for number of weighting functions defined  (io) !
!   sq     - real, cross section x quantum yield (cm^2) for each          (o) !
!            photolysis reaction defined, at each defined wavelength and      !
!            at each defined altitude level                                   !
!   jlabel - character*60, string identifier for each photolysis reaction (o) !
!            defined                                                          !
!-----------------------------------------------------------------------------!
!   edit history:                                                             !
!   05/98  original, adapted from former jspec1 subroutine                    !
!-----------------------------------------------------------------------------!
!  this program is free software;  you can redistribute it and/or modify      !
!  it under the terms of the gnu general public license as published by the   !
!  free software foundation;  either version 2 of the license, or (at your    !
!  option) any later version.                                                 !
!  the tuv package is distributed in the hope that it will be useful, but     !
!  without any warranty;  without even the implied warranty of merchantibi-   !
!  lity or fitness for a particular purpose.  see the gnu general public      !
!  license for more details.                                                  !
!  to obtain a copy of the gnu general public license, write to:              !
!  free software foundation, inc., 675 mass ave, cambridge, ma 02139, usa.    !
!-----------------------------------------------------------------------------!
      implicit none
      include 'params'

!-----------------------------------------------------------------------------!
!     ... input                                                               !
!-----------------------------------------------------------------------------!
      real, intent(in) :: wl(kw)
      real, intent(in) :: wc(kw)
      real, intent(in) :: tlev(kz)
      real, intent(in) :: airlev(kz)

      integer, intent(in) :: nz
      integer, intent(in) :: nw

      character*80, intent(in) ::  pn
      character*60, intent(out) :: jlabel(kj)
      real, intent(out) :: sq(kj,kz,kw)

!-----------------------------------------------------------------------------!
!     ... input/output                                                        !
!-----------------------------------------------------------------------------!
      integer, intent(inout) :: j

!-----------------------------------------------------------------------------!
!     ... local                                                               !
!-----------------------------------------------------------------------------!
      integer iz, iw, n
      integer kdata
      parameter(kdata=16000)
      real x(kdata), y(kdata)
      real xl(kdata), xc(kdata), xu(kdata)
      integer n1, n2, n3, n4, n5
      real x1(kdata), x2(kdata), x3(kdata), x4(kdata), x5(kdata)
      real y1(kdata), y2(kdata), y3(kdata), y4(kdata), y5(kdata)

      real yg(kw), yg1(kw), yg2(kw), yg3(kw), yg4(kw), yg5(kw)
      real a, b, c, a0, a1, a2, a3, a4, a5, a6, a7
      real b0, b1, b2, b3, b4
      real phi1, phi2, phi20, ak300, akt
      real qy, qy1, qy2, qy3
      real sigma, sig, slope, xs, t, dum, idum
      integer i, irow, icol, irev, ierr, mopt1, mopt2

!      do iw = 1, nw - 1
!         wc(iw) = (wl(iw) + wl(iw+1))/2.
!      end do
!----------------------------------------------
!     ... jlabel(j) = 'CH2O -> H + HCO'
!         jlabel(j) = 'CH2O -> H2 + CO'
!----------------------------------------------
      j = j+1
      jlabel(j) = 'CH2O + hv -> H + HCO' 

      j = j+1
      jlabel(j) = 'CH2O + hv -> H2 + CO'

!-------------------------------------------------------------------------------
!     ... working grid arrays:
!         yg1 = cross section at a specific temperature
!         yg2, yg3 = cross sections at different temp or slope, for calculating
!                    temperature depedence
!         yg4 = quantum yield data for radical channel
!         yg5 = quantum yield data for molecular channel
!
!     input data options:
!
!     ... mopt1 for absorption:
!     1:  dataj1/ch2o/ch2o_nbs.abs'
!         from bass et al., planet. space. sci. 28, 675, 1980.
!         over 258.750-359.525 in 0.025 nm steps
!     2:  dataj1/ch2o_iupac1.abs 
!         moortgat and schneider, personal communication as reported in iupac 89, 92, 97
!         at 285k.  over 240-360 nm in 1 nm bins (note that iupac 89,92,97 incorectly 
!         claims 0.5 nm intervals in footnote)
!     3:  dataj1/ch2o/ch2o_can_hr.abs for wc > 301 nm, temperature dependent
!         dataj1/ch2o/ch2o_iupac1.abs elsewhere
!         from cantrell et al. 1990 for wc > 301 nm.  original data from cantrell,
!         at high resolution
!     4:  dataj1/ch2o/ch2o_can_lr.abs for wc > 301 nm, temperature dependent
!         dataj1/ch2o/ch2o_iupac1.abs elsewhere
!         from cantrell et al. 1990 for wc > 301 nm.  data from cantrell et al., as
!         reported by iupac'92,'97.  on 2.5 nm intervals.
!     5:  dataj1/ch2o/ch2o_rog.abs'
!         from rogers et al., j. phys. chem. 94, 4011, 1990.
!     6:  dataj2/ch2o_ncar.abs
!         new ncar recommendation, based on averages of moortgat and schneider, cantrell et al.,
!         and rogers.
!
!     ... mopt2 for quantum yields:
!     1:  dataj1/ch2o/ch2o_i_mad.yld and 
!         dataj1/ch2o/ch2o_ii_mad.yld
!         evaluated by madronich, 1991, unpublished
!     2:  dataj1/ch2o/ch2o_iupac.yld
!         from iupac'89, '92, '97
!     3:  dataj1/ch2o/ch2o_jpl97.dat'
!         based on madronich 1991 unpublished evaluation, updated jan 1998.
!-----------------------------------------------------------------------------------
      mopt1 = 6
      mopt2 = 1

      if (mopt1 .eq. 1) then
!------------------------------
!     ... read nbs/bass data
!------------------------------
         open(unit=kin,file=TRIM(pn)//'CH2O_nbs.abs'
     $        ,status='old')
         n = 4032
         do i = 1, n
            read(kin,*) x(i), y(i)
         enddo
         call addpnt(x,y,kdata,n,x(1)*(1.-deltax),0.)
         call addpnt(x,y,kdata,n,               0.,0.)
         call addpnt(x,y,kdata,n,x(n)*(1.+deltax),0.)
         call addpnt(x,y,kdata,n,           1.e+38,0.)

         call inter2(nw,wl,yg1,n,x,y,ierr)
         if (ierr .ne. 0) then
            write(*,*) ierr, jlabel(j-1)
            stop
         endif

      elseif (mopt1 .eq. 2 .or. mopt1 .eq. 3 .or. mopt1 .eq. 4) then

         open(unit=kin,
     &        file=TRIM(pn)//'CH2O_iupac1.abs',status='old')
         do i = 1, 4
            read(kin,*)
         enddo
         n = 121
         do i = 1, n
            read(kin,*) x(i), y(i)
            y(i) = y(i) * 1.e-20
         enddo
         close(kin)
         call addpnt(x,y,kdata,n,x(1)*(1.-deltax),0.)
         call addpnt(x,y,kdata,n,               0.,0.)
         call addpnt(x,y,kdata,n,x(n)*(1.+deltax),0.)
         call addpnt(x,y,kdata,n,           1.e+38,0.)
         call inter2(nw,wl,yg1,n,x,y,ierr)
         if (ierr .ne. 0) then
            write(*,*) ierr, jlabel(j-1)
            stop
         endif

         if(mopt1 .eq. 3) then
!---------------------------------------------------------------------------------
!     ... data are on wavenumber grid (cm-1), so convert to wavelength in nm:
!         grid was on increasing wavenumbers, so need to reverse to get increasing
!         wavelengths
!         cross section assumed to be zero for wavelengths longer than 360 nm
!         if y1 < 0, then make = 0 (some negative cross sections, 
!         actually 273 k intercepts are in the original data,  here, 
!         make equal to zero)
!---------------------------------------------------------------------------------
         open(kin,
     &        file=TRIM(pn)//'CH2O_can_hr.abs',status='old')
         read(kin,*) idum, n
         do i = 1, idum-2
            read(kin,*)
         enddo
         do i = 1, n
            read(kin,*) x1(i), y1(i), y2(i)
            x1(i) = 1./x1(i) * 1e7
            if (x1(i) .gt. 360.) then
               y1(i) = 0.
               y2(i) = 0.
            endif
         enddo
         close(kin)

         do i = 1, n/2
            irev = n+1-i
            dum = x1(i)
            x1(i) = x1(irev)
            x1(irev) = dum
            dum = y1(i)
            y1(i) = y1(irev)
            y1(irev) = dum
            dum = y2(i)
            y2(i) = y2(irev)
            y2(irev) = dum
         enddo
         do i = 1, n
            x2(i) = x1(i)
            y1(i) = max(y1(i),0.)
         enddo
         n1 = n
         n2 = n

         call addpnt(x1,y1,kdata,n1,x1(1)*(1.-deltax),0.)
         call addpnt(x1,y1,kdata,n1,               0.,0.)
         call addpnt(x1,y1,kdata,n1,x1(n1)*(1.+deltax),0.)
         call addpnt(x1,y1,kdata,n1,             1e38,0.)
         call inter2(nw,wl,yg2,n1,x1,y1,ierr)
         if (ierr .ne. 0) then
            write(*,*) ierr, jlabel(j)
            stop
         endif

         call addpnt(x2,y2,kdata,n2,x2(1)*(1.-deltax),0.)
         call addpnt(x2,y2,kdata,n2,               0.,0.)
         call addpnt(x2,y2,kdata,n2,x2(n2)*(1.+deltax),0.)
         call addpnt(x2,y2,kdata,n2,              1e38,0.)
         call inter2(nw,wl,yg3,n2,x2,y2,ierr)
         if (ierr .ne. 0) then
            write(*,*) ierr, jlabel(j)
            stop
         endif

      elseif(mopt1 .eq. 4) then

            open(unit=kin,file=TRIM(pn)//'CH2O_can_lr.abs',
     $        status='old')
            do i = 1, 4
               read(kin,*)
            enddo
            n = 23
            do i = 1, n
               read(kin,*) x2(i), y2(i), y3(i), dum, dum
               x3(i) = x2(i)
            enddo
            close(kin)
            n2 = n
            n3 = n

            call addpnt(x2,y2,kdata,n2,x2(1)*(1.-deltax),0.)
            call addpnt(x2,y2,kdata,n2,               0.,0.)
            call addpnt(x2,y2,kdata,n2,x2(n2)*(1.+deltax),0.)
            call addpnt(x2,y2,kdata,n2,             1e38,0.)
            call inter2(nw,wl,yg2,n2,x2,y2,ierr)
            if (ierr .ne. 0) then
               write(*,*) ierr, jlabel(j)
               stop
            endif

            call addpnt(x3,y3,kdata,n3,x3(1)*(1.-deltax),0.)
            call addpnt(x3,y3,kdata,n3,               0.,0.)
            call addpnt(x3,y3,kdata,n3,x3(n3)*(1.+deltax),0.)
            call addpnt(x3,y3,kdata,n3,              1e38,0.)
            call inter2(nw,wl,yg3,n3,x3,y3,ierr)
            if (ierr .ne. 0) then
               write(*,*) ierr, jlabel(j)
               stop
            endif

         endif

      elseif (mopt1 .eq. 5) then
!------------------------------
!     ... read rodgers data
!------------------------------
         open(unit=kin,file=TRIM(pn)//'CH2O_rog.abs'
     $        ,status='old')
         do i = 1, 10
            read(kin,*)
         enddo
         n = 261
         do i = 1, n
            read(kin,*) x(i), y(i), dum
            y(i) = y(i) * 1.e-20
         enddo
         call addpnt(x,y,kdata,n,x(1)*(1.-deltax),0.)
         call addpnt(x,y,kdata,n,               0.,0.)
         call addpnt(x,y,kdata,n,x(n)*(1.+deltax),0.)
         call addpnt(x,y,kdata,n,           1.e+38,0.)
         call inter2(nw,wl,yg1,n,x,y,ierr)
         if (ierr .ne. 0) then
            write(*,*) ierr, jlabel(j-1)
            stop
         endif

      elseif(mopt1 .eq. 6) then

            open(unit=kin,
     &      file=TRIM(pn)//'CH2O_ncar.abs',status='old')
            do i = 1, 3
               read(kin,*)
            enddo
            n = 126
            do i = 1, n
               read(kin,*) x2(i), y2(i), y3(i)
               x3(i) = x2(i)
            enddo
            close(kin)
            n2 = n
            n3 = n

            call addpnt(x2,y2,kdata,n2,x2(1)*(1.-deltax),0.)
            call addpnt(x2,y2,kdata,n2,               0.,0.)
            call addpnt(x2,y2,kdata,n2,x2(n2)*(1.+deltax),0.)
            call addpnt(x2,y2,kdata,n2,             1e38,0.)
            call inter2(nw,wl,yg2,n2,x2,y2,ierr)
            if (ierr .ne. 0) then
               write(*,*) ierr, jlabel(j)
               stop
            endif

            call addpnt(x3,y3,kdata,n3,x3(1)*(1.-deltax),0.)
            call addpnt(x3,y3,kdata,n3,               0.,0.)
            call addpnt(x3,y3,kdata,n3,x3(n3)*(1.+deltax),0.)
            call addpnt(x3,y3,kdata,n3,              1e38,0.)
            call inter2(nw,wl,yg3,n3,x3,y3,ierr)
            if (ierr .ne. 0) then
               write(*,*) ierr, jlabel(j)
               stop
            endif

      endif
!--------------------------------------------     
!     ... quantum yield
!--------------------------------------------     

      if (mopt2 .eq. 1) then

         open(unit=kin,
     &        file=TRIM(pn)//'CH2O_i_mad.yld',status='old')
         do i = 1, 11
            read(kin,*)
         enddo
         n = 20
         do i = 1, n
            read(kin,*) x(i), y(i)
         enddo
         close(kin)
         call addpnt(x,y,kdata,n,x(1)*(1.-deltax),y(1))
         call addpnt(x,y,kdata,n,               0.,y(1))
         call addpnt(x,y,kdata,n,x(n)*(1.+deltax),0.)
         call addpnt(x,y,kdata,n,           1.e+38,0.)
         call inter2(nw,wl,yg4,n,x,y,ierr)
         if (ierr .ne. 0) then
            write(*,*) ierr, jlabel(j-1)
            stop
         endif

         open(unit=kin,
     &        file=TRIM(pn)//'CH2O_ii_mad.yld',status='old')
         do i = 1, 9
            read(kin,*)
         enddo
         n = 33
         do i = 1, n
            read(kin,*) x(i), y(i)
         enddo
         close(kin)
         call addpnt(x,y,kdata,n,x(1)*(1.-deltax),y(1))
         call addpnt(x,y,kdata,n,               0.,y(1))
         call addpnt(x,y,kdata,n,x(n)*(1.+deltax),0.)
         call addpnt(x,y,kdata,n,           1.e+38,0.)
         call inter2(nw,wl,yg5,n,x,y,ierr)
         if (ierr .ne. 0) then
            write(*,*) ierr, jlabel(j)
            stop
         endif

      elseif(mopt2 .eq. 2) then

         open(unit=kin,
     &        file='INPUT/QUANTUM_YIELDS/CH2O_iupac.yld',status='old')
         do i = 1, 7
            read(kin,*) 
         enddo
         n = 13
         do i = 1, n
            read(kin,*) x1(i), y1(i), y2(i)
            x2(i) = x1(i)
         enddo
         close(kin)
         n1 = n
         n2 = n

         call addpnt(x1,y1,kdata,n1,x1(1)*(1.-deltax),y1(1))
         call addpnt(x1,y1,kdata,n1,               0.,y1(1))
         call addpnt(x1,y1,kdata,n1,x1(n1)*(1.+deltax),0.)
         call addpnt(x1,y1,kdata,n1,           1.e+38,0.)
         call inter2(nw,wl,yg4,n1,x1,y1,ierr)
         if (ierr .ne. 0) then
            write(*,*) ierr, jlabel(j)
            stop
         endif

         call addpnt(x2,y2,kdata,n2,x2(1)*(1.-deltax),y2(1))
         call addpnt(x2,y2,kdata,n2,               0.,y2(1))
         call addpnt(x2,y2,kdata,n2,x2(n2)*(1.+deltax),0.)
         call addpnt(x2,y2,kdata,n2,           1.e+38,0.)
         call inter2(nw,wl,yg5,n2,x2,y2,ierr)
         if (ierr .ne. 0) then
            write(*,*) ierr, jlabel(j)
            stop
         endif


      else if(mopt2 .eq. 3) then

         open(unit=kin,
     &        file='INPUT/QUANTUM_YIELD/CH2O_jpl97.dat',status='old')
         do i = 1, 4
            read(kin,*) 
         enddo
         n = 23
         do i = 1, n
            read(kin,*) x1(i), dum, dum, dum, dum, y1(i), y2(i)
            x2(i) = x1(i)
         enddo
         close(kin)
         n1 = n
         n2 = n

         call addpnt(x1,y1,kdata,n1,x1(1)*(1.-deltax),y1(1))
         call addpnt(x1,y1,kdata,n1,               0.,y1(1))
         call addpnt(x1,y1,kdata,n1,x1(n1)*(1.+deltax),0.)
         call addpnt(x1,y1,kdata,n1,           1.e+38,0.)
         call inter2(nw,wl,yg4,n1,x1,y1,ierr)
         if (ierr .ne. 0) then
            write(*,*) ierr, jlabel(j)
            stop
         endif

         call addpnt(x2,y2,kdata,n2,x2(1)*(1.-deltax),y2(1))
         call addpnt(x2,y2,kdata,n2,               0.,y2(1))
         call addpnt(x2,y2,kdata,n2,x2(n2)*(1.+deltax),0.)
         call addpnt(x2,y2,kdata,n2,           1.e+38,0.)
         call inter2(nw,wl,yg5,n2,x2,y2,ierr)
         if (ierr .ne. 0) then
            write(*,*) ierr, jlabel(j)
            stop
         endif

      endif
!--------------------------------------------------------
!     ... combine
!         y1 = xsect
!         y2 = xsect(223), cantrell et al.
!         y3 = xsect(293), cantrell et al.
!         y4 = qy for radical channel
!         y5 = qy for molecular channel
!        pressure and temperature dependent for w > 330.
!--------------------------------------------------------

      do iw = 1, nw - 1

         if (mopt1 .eq. 6) then
            sig = yg2(iw)
         else
            sig = yg1(iw)
         endif

         do i = 1, nz
!---------------------------------------------------------------------
!     correct cross section for temperature dependence for > 301. nm
!---------------------------------------------------------------------
        
            if (wl(iw) .ge. 301.) then 
               t = max(223.15, min(tlev(i), 293.15))
               if (mopt1 .eq. 3 .or. mopt1 .eq. 6) then
                  sig = yg2(iw) + yg3(iw) * (t - 273.15)

               elseif (mopt1 .eq. 4) then
                  slope = (yg3(iw) - yg2(iw)) / (293. - 223.)
                  sig = yg2(iw) + slope * (t - 223.)

               endif

            endif
            sig = max(sig, 0.)
!---------------------------------------------------------------------
!     ... quantum yields:
!         temperature and pressure dependence beyond 330 nm
!---------------------------------------------------------------------
            qy1 = yg4(iw)
            if ( (wc(iw) .ge. 330.) .and. (yg5(iw) .gt. 0.) ) then
               phi1 = yg4(iw)
               phi2 = yg5(iw)
               phi20 = 1. - phi1
               ak300=((1./phi2)-(1./phi20))/2.54e+19
               akt=ak300*(1.+61.69*(1.-tlev(i)/300.)*(wc(iw)/329.-1.))
               qy2 = 1. / ( (1./phi20) + airlev(i)*akt)

            else
               qy2 = yg5(iw)
            endif
            qy2 = max(0.,qy2)
            qy2 = min(1.,qy2)
            
            sq(j-1,i,iw) = sig * qy1
            sq(j  ,i,iw) = sig * qy2

         enddo
      enddo

      end subroutine XSQY_CH2O
