      subroutine XSQY_CH2O(nw,wl,wc,nz,tlev,airlev,j,sq,jlabel,pn)
!-----------------------------------------------------------------------------!
!   purpose:                                                                  !
!   provide product of (cross section) x (quantum yield) for ch2o photolysis  !
!         (a) CH2O + hv -> H + HCO                                            !
!         (b) CH2O + hv -> H2 + CO                                            !
!-----------------------------------------------------------------------------!
!   parameters:                                                               !
!   nw     - integer, number of specified intervals + 1 in working        (i) !
!            wavelength grid                                                  !
!   wl     - real, vector of lower limits of wavelength intervals in      (i) !
!            working wavelength grid                                          !
!   wc     - real, vector of center points of wavelength intervals in     (i) !
!            working wavelength grid                                          !
!   nz     - integer, number of altitude levels in working altitude grid  (i) !
!   tlev   - real, temperature (k) at each specified altitude level       (i) !
!   airlev - real, air density (molec/cc) at each altitude level          (i) !
!   j      - integer, counter for number of weighting functions defined  (io) !
!   sq     - real, cross section x quantum yield (cm^2) for each          (o) !
!            photolysis reaction defined, at each defined wavelength and      !
!            at each defined altitude level                                   !
!   jlabel - character*60, string identifier for each photolysis reaction (o) !
!            defined                                                          !
!-----------------------------------------------------------------------------!
!   edit history:                                                             !
!   02/13/08 Doug Kinnison                                                    !
!-----------------------------------------------------------------------------!
      implicit none
      include 'params'

!-----------------------------------------------------------------------------!
!     ... input                                                               !
!-----------------------------------------------------------------------------!
      real, intent(in) :: wl(kw)
      real, intent(in) :: wc(kw)
      real, intent(in) :: tlev(kz)
      real, intent(in) :: airlev(kz)

      integer, intent(in) :: nz
      integer, intent(in) :: nw

      character*80, intent(in) ::  pn
      character*60, intent(out) :: jlabel(kj)
      real, intent(out) :: sq(kj,kz,kw)

!-----------------------------------------------------------------------------!
!     ... input/output                                                        !
!-----------------------------------------------------------------------------!
      integer, intent(inout) :: j

!-----------------------------------------------------------------------------!
!     ... local                                                               !
!-----------------------------------------------------------------------------!

      integer kdata
      parameter(kdata=200)

      integer iz, iw
      integer i, ierr, idum
      integer n, n1, n2
      real x  (kdata), y (kdata)
      real x1 (kdata), x2(kdata), x3(kdata)
      real y1 (kdata), y2(kdata), y3(kdata)
      real yt (kz,kdata)
      real yg (kw), yg4(kw), yg5(kw)
      real yg1(kz,kw)
      real tin(kz)
      real qy1, qy2
      real phi1, phi2, phi20, ak300, akt,sig
      character*80 fn

!----------------------------------------------
!     ... tin set to tlev
!----------------------------------------------
      tin(:) = tlev(:)
!----------------------------------------------
!     ... jlabel(j) = 'CH2O -> H + HCO'
!         jlabel(j) = 'CH2O -> H2 + CO'
!----------------------------------------------
      j = j+1
      jlabel(j) = 'CH2O + hv -> H + HCO' 

      j = j+1
      jlabel(j) = 'CH2O + hv -> H2 + CO'

!----------------------------------------------
!     ... cross sections
!----------------------------------------------
      open(kin,file=TRIM(pn)//'XS_CH2O_model_JPL06.txt',status='old')

      read(kin,*) idum, n1
      do i = 1, idum-2
        read(kin,*)
      enddo

      do i = 1, n1
        read(kin,*) x1(i), y1(i)
!        print*, x1(i), y1(i)
      enddo
      close(kin)
 
!----------------------------------------------
!     ... slope - temperature Dep
!----------------------------------------------
      fn = 'XS_CH2O_model_slope_JPL06.txt'
      open(kin,file=TRIM(pn)//fn,status='old')

      read(kin,*) idum, n2
      do i = 1, idum-2
        read(kin,*)
      enddo

      do i = 1, n2
        read(kin,*) x2(i+9), y2(i+9)
         y2(i+9) = y2(i+9) * 1e-24
!        print*, x2(i+9), y2(i+9)
      enddo
      close(kin)      

!----------------------------------------------
!     ... cross sections - temperature Dep
!----------------------------------------------
      do iz = 1, nz
        do iw = 1, n1
      
          IF (x1(iw) .LT. 251.6) THEN 
             yt(iz,iw) = y1(iw)
          ENDIF

!...      Wavelengeth and temperature dependence
          IF ((x1(iw) .GE. 251.6) .AND. (x1(iw) .LE. 350.)) THEN 
            IF (tin(iz) .LT. 223.0) THEN
              yt(iz,iw) = y1(iw) + y2(iw) * (223.0 - 298.)
            ENDIF

            IF (tin(iz) .GT. 323.0) THEN
              yt(iz,iw) = y1(iw) + y2(iw) * (323.0 - 298.)
              
            ENDIF
            IF ((tin(iz) .GE. 223.0) .AND.(tin(iz) .LE. 323.0)) THEN
              yt(iz,iw) = y1(iw) + y2(iw) * (tin(iz) - 298.)
            ENDIF
          ENDIF

          IF (x1(iw) .GT. 350.) THEN
             yt(iz,iw) = y1(iw)
          ENDIF
        enddo
      enddo

!----------------------------------------------
!     ... Check routine 
!      iz = 1
!      print*,'tin=', tin(iz)
!      print*, n1
!      do iw = 1,n1
!        print*, iw, x1(iw), yt(iz,iw)
!      enddo
!      stop
!----------------------------------------------
!----------------------------------------------
!     ... interpolate
!----------------------------------------------
      do iz = 1, nz
        x3(:) = x1(:)
        y3(:) = yt(iz,:)
        n     = n1
  
        call addpnt(x3, y3, kdata, n, x3(1)*(1.-deltax), 0.)
        call addpnt(x3, y3, kdata, n, 0.,                0.)
        call addpnt(x3, y3, kdata, n, x3(n)*(1.+deltax), 0.)
        call addpnt(x3, y3, kdata, n, 1e38,              0.)

        call inter2(nw,wl,yg,   n,x3, y3, ierr)
 
        yg1(iz,:) = yg(:)

        if (ierr .ne. 0) then
          write(*,*) ierr, jlabel(j)
          stop
        endif  
      enddo
!----------------------------------------------
!     ... Check routine 
!      iz = 1
!      print*,'tin=', tin(iz)
!      do iw = 43, 84
!        print*, iw, wc(iw), yg1(iz,iw)
!      enddo
!      stop
!----------------------------------------------

!----------------------------------------------
!     ... quantum yields
!----------------------------------------------
      open(kin,file=TRIM(pn)//'QY_CH2O_JPL06.txt',status='old')

      read(kin,*) idum, n1
      do i = 1, idum-2
        read(kin,*)
      enddo

      do i = 1, n1
        read(kin,*) x1(i), y1(i), y2(i)
!       print*,  x1(i), y1(i), y2(i)
      enddo
      close(kin)

!...  interpolate y1
      n = n1
      y = y1
      x = x1

      call addpnt(x,y,kdata,n,x(1)*(1.-deltax),y(1))
      call addpnt(x,y,kdata,n,               0.,y(1))
      call addpnt(x,y,kdata,n,x(n)*(1.+deltax),0.)
      call addpnt(x,y,kdata,n,           1.e+38,0.)
      call inter2(nw,wl,yg4,n,x,y,ierr)
      if (ierr .ne. 0) then
          write(*,*) ierr, jlabel(j-1)
          stop
      endif

!...  interpolate y2    
      n = n1  
      y = y2
      x = x1   
      call addpnt(x,y,kdata,n,x(1)*(1.-deltax),y(1))
      call addpnt(x,y,kdata,n,               0.,y(1))
      call addpnt(x,y,kdata,n,x(n)*(1.+deltax),0.)
      call addpnt(x,y,kdata,n,           1.e+38,0.)
      call inter2(nw,wl,yg5,n,x,y,ierr)
      if (ierr .ne. 0) then
          write(*,*) ierr, jlabel(j)
          stop
      endif
!----------------------------------------------
!     ... Check routine 
!      do iw = 43, 84
!        print*, iw, wc(iw), yg4(iw),yg5(iw)
!      enddo
!      stop
!----------------------------------------------
!----------------------------------------------
!     ... quantum yields:
!         temperature and pressure dependence 
!         beyond 330 nm
!----------------------------------------------
      do iw = 1, nw - 1
        do iz = 1, nz
            qy1 = yg4(iw)
            if ( (wc(iw) .ge. 330.) .and. (yg5(iw) .gt. 0.) ) then
               phi1 = yg4(iw)
               phi2 = yg5(iw)
               phi20 = 1. - phi1
               ak300=((1./phi2)-(1./phi20))/2.54e+19
               akt=ak300*(1.+61.69*(1.-tin(iz)/300.)*(wc(iw)/329.-1.))
               qy2 = 1. / ( (1./phi20) + airlev(iz)*akt)

            else
               qy2 = yg5(iw)
            endif
            qy2 = max(0.,qy2)
            qy2 = min(1.,qy2)
            
            sq(j-1,iz,iw) = yg1(iz,iw) * qy1
            sq(j  ,iz,iw) = yg1(iz,iw) * qy2
         enddo
       enddo

!----------------------------------------------
!     ... Check routine 
!       iz = 50
!       print*, 'tin=', tin(iz)
!       print*, 'ad =', airlev(iz)
!       do iw = 43,84
!         print*, iw, wc(iw), yg1(iz,iw),sq(j-1,iz,iw), sq(j,iz,iw)
!       enddo
!       stop
!----------------------------------------------
!      print*, "* CH2O QY2 T/P dep chk"
      end subroutine XSQY_CH2O
