      SUBROUTINE XSQY_CH3CHO(nw,wl,wc,nz,tlev,airden,j,sq,jlabel,pn)
!---------------------------------------------------------------------------!
!  PURPOSE:                                                                 !
!  Provide product (cross section) x (quantum yield) for CH3CHO photolysis: !
!      (a)  CH3CHO + hv -> CH3 + HCO                                        !
!      (b)  CH3CHO + hv -> CH4 + CO                                         !
!      (c)  CH3CHO + hv -> CH3CO + H                                        !
!  Cross section:  Choice between                                           !
!                   (1) IUPAC 97 data, from Martinez et al.                 !
!                   (2) Calvert and Pitts                                   !
!                   (3) Martinez et al., Table 1 scanned from paper         !
!                   (4) KFA tabulations                                     !
!  Quantum yields: Choice between                                           !
!                   (1) IUPAC 97, pressure correction using Horowith and    !
!                                 Calvert, 1982                             !
!                   (2) NCAR data file, from Moortgat, 1986                 !
!---------------------------------------------------------------------------!
!  PARAMETERS:                                                              !
!  NW     - INTEGER, number of specified intervals + 1 in working        (I)!
!           wavelength grid                                                 !
!  WL     - REAL, vector of lower limits of wavelength intervals in      (I)!
!           working wavelength grid                                         !
!  WC     - REAL, vector of center points of wavelength intervals in     (I)!
!           working wavelength grid                                         !
!  NZ     - INTEGER, number of altitude levels in working altitude grid  (I)!
!  TLEV   - REAL, temperature (K) at each specified altitude level       (I)!
!  AIRDEN - REAL, air density (molec/cc) at each altitude level          (I)!
!  J      - INTEGER, counter for number of weighting functions defined  (IO)!
!  SQ     - REAL, cross section x quantum yield (cm^2) for each          (O)!
!           photolysis reaction defined, at each defined wavelength and     !
!           at each defined altitude level                                  !
!  JLABEL - CHARACTER*50, string identifier for each photolysis reaction (O)!
!           defined                                                         !
!---------------------------------------------------------------------------!
      IMPLICIT NONE
      INCLUDE 'params'

!-----------------------------------------------------------------------------!
!     ... input                                                               !
!-----------------------------------------------------------------------------!
      real, intent(in) :: wl(kw)
      real, intent(in) :: wc(kw)
      real, intent(in) :: tlev(kz)
      real, intent(in) :: airden(kz)

      integer, intent(in) :: nz
      integer, intent(in) :: nw

      character*80, intent(in) ::  pn
      character*60, intent(out) :: jlabel(kj)
      real, intent(out) :: sq(kj,kz,kw)

!-----------------------------------------------------------------------------!
!     ... input/output                                                        !
!-----------------------------------------------------------------------------!
      integer, intent(inout) :: j

!-----------------------------------------------------------------------------!
!     ... local                                                               !
!-----------------------------------------------------------------------------!
      integer kdata
      parameter (kdata=150)

      integer  i, n, n1, n2, ierr, iz, iw, idum
      real  x1(kdata), x2(kdata)
      real  y1(kdata), y2(kdata)
      real  yg(kw), yg1(kw), yg2(kw), yg3(kw), yg4(kw)
      real  qy1, qy2, qy3
      real  sig
      real  dum

!----------------------------------------------------
!... CH3CHO photolysis
!       1:  CH3 + HCO
!       2:  CH4 + CO
!       3:  CH3CO + H
!----------------------------------------------------
!      j = j+1
!      jlabel(j) = 'ch3cho -> ch3 + hco'	
!      j = j+1
!      jlabel(j) = 'ch3cho -> ch4 + co'	
!      j = j+1
!      jlabel(j) = 'ch3cho -> ch3co + h'
!----------------------------------------------------
      j = j + 1
      jlabel(j)  = 'CH3CHO + hv -> CH3O2 + CO + HO2'
	
!----------------------------------------------------
!... Absorption cross sections (JPL06)
!----------------------------------------------------
      open(UNIT=kin,FILE=
     &   TRIM(pn)//'XS_CH3CHO_JPL06.txt',STATUS='old')

      read(kin,*) idum, n
      do i = 1, idum-2
        read(kin,*)
      enddo

      do i = 1, n
        read(kin,*) x1(i), y1(i)
      enddo
      close(kin)
      
      call addpnt(x1,y1,kdata,n,x1(1)*(1.-deltax),0.)
      call addpnt(x1,y1,kdata,n,          0.,0.)
      call addpnt(x1,y1,kdata,n,x1(n)*(1.+deltax),0.)
      call addpnt(x1,y1,kdata,n,        1e38,0.)
      call inter2(nw,wl,yg,   n,x1,     y1,ierr)

      if (ierr .ne. 0) then
        write(*,*) ierr, jlabel(j)
        stop
      endif

!----------------------------------------------------
!... Quantum yield
!      DATAJ1/CH3CHO/CH3CHO_iup.y1d
!      pressure correction using Horowitz and 
!      Calvert 1982, based on slope/intercept
!      of Stern-Volmer plots
!----------------------------------------------------
      open(UNIT=kin,FILE=
     &   TRIM(pn)//'QY_CH3CHO_iup.yld.txt',STATUS='old')
      do i = 1, 4
         read(kin,*)
      enddo
      n = 12
      DO i = 1, n
         READ(kin,*) x1(i), y2(i), y1(i)
         x2(i) = x1(i)
      ENDDO
      CLOSE(kin)
      n1 = n
      n2 = n

      CALL addpnt(x1,y1,kdata,n1,x1(1)*(1.-deltax),0.)
      CALL addpnt(x1,y1,kdata,n1,               0.,0.)
      CALL addpnt(x1,y1,kdata,n1,x1(n1)*(1.+deltax),0.)
      CALL addpnt(x1,y1,kdata,n1,           1.e+38,0.)
      CALL inter2(nw,wl,yg1,n1,x1,y1,ierr)
      IF (ierr .NE. 0) THEN
         WRITE(*,*) ierr, jlabel(j)
         STOP
      ENDIF

      CALL addpnt(x2,y2,kdata,n2,x2(1)*(1.-deltax),0.)
      CALL addpnt(x2,y2,kdata,n2,               0.,0.)
      CALL addpnt(x2,y2,kdata,n2,x2(n2)*(1.+deltax),0.)
      CALL addpnt(x2,y2,kdata,n2,           1.e+38,0.)
      CALL inter2(nw,wl,yg2,n2,x2,y2,ierr)
      IF (ierr .NE. 0) THEN
         WRITE(*,*) ierr, jlabel(j)
         STOP
      ENDIF

      do iw = 1, nw-1
          yg3(iw) = 0.
      enddo

!----------------------------------------------------
!... pressure-dependence parameters
!----------------------------------------------------
      OPEN(UNIT=kin,FILE=
     &  TRIM(pn)//'QY_CH3CHO_press.yld.txt',
     $     STATUS='old')
      do i = 1, 4
         read(kin,*)
      enddo
      n = 5
      DO i = 1, n
         READ(kin,*) x1(i), dum, dum, y1(i)
      ENDDO
      CLOSE (kin)

      CALL addpnt(x1,y1,kdata,n,x1(1)*(1.-deltax),0.)
      CALL addpnt(x1,y1,kdata,n,               0.,0.)
      CALL addpnt(x1,y1,kdata,n,x1(n)*(1.+deltax),0.)
      CALL addpnt(x1,y1,kdata,n,           1.e+38,0.)
      CALL inter2(nw,wl,yg4,n,x1,y1,ierr)

      IF (ierr .NE. 0) THEN
         WRITE(*,*) ierr, jlabel(j)
         STOP
      ENDIF

!----------------------------------------------------
!...  combine XS*QY 
!----------------------------------------------------
      DO iw = 1, nw - 1
         DO i = 1, nz

            sig = yg(iw)
            qy1 = yg1(iw)
            qy2 = yg2(iw)
            qy3 = yg3(iw)

!... Pressure correction for channel 1, CH3 + CHO
!     based on Horowitz and Calvert 1982.

            qy1 = qy1 * (1. + yg4(iw))/(1. + yg4(iw)*airden(i)/2.465E19)
            qy1 = MIN(1., qy1)
            qy1 = MAX(0., qy1)

            sq(j  ,i,iw) = (sig*qy1)+(sig*qy2) + (sig * qy3)

         ENDDO
      ENDDO

      end subroutine XSQY_CH3CHO
