      subroutine XSQY_CH3I(nw,wl,wc,nz,tlev,airlev,j,sq,jlabel,pn)
!-----------------------------------------------------------------------------!
!   purpose:                                                                  !
!   provide product (cross section) x (quantum yield):                        !
!           CH3I + hv -> I                                                    !
!   cross section: JPL 10-6                                                   !
!-----------------------------------------------------------------------------!
!   parameters:                                                               !
!   nw     - integer, number of specified intervals + 1 in working        (i) !
!            wavelength grid                                                  !
!   wl     - real, vector of lower limits of wavelength intervals in      (i) !
!            working wavelength grid                                          !
!   wc     - real, vector of center points of wavelength intervals in     (i) !
!            working wavelength grid                                          !
!   nz     - integer, number of altitude levels in working altitude grid  (i) !
!   tlev   - real, temperature (k) at each specified altitude level       (i) !
!   airlev - real, air density (molec/cc) at each altitude level          (i) !
!   j      - integer, counter for number of weighting functions defined  (io) !
!   sq     - real, cross section x quantum yield (cm^2) for each          (o) !
!            photolysis reaction defined, at each defined wavelength and      !
!            at each defined altitude level                                   !
!   jlabel - character*60, string identifier for each photolysis reaction (o) !
!            defined                                                          !
!-----------------------------------------------------------------------------!
!   edit history:                                                             !
!   04/05/08  Doug Kinnison                                                   !
!-----------------------------------------------------------------------------!
      implicit none
      include 'params'

!-----------------------------------------------------------------------------!
!     ... input                                                               !
!-----------------------------------------------------------------------------!
      real, intent(in) :: wl(kw)
      real, intent(in) :: wc(kw)
      real, intent(in) :: tlev(kz)
      real, intent(in) :: airlev(kz)

      integer, intent(in) :: nz
      integer, intent(in) :: nw

      character*80, intent(in)  ::  pn
      character*60, intent(out) :: jlabel(kj)
      real, intent(out)         :: sq(kj,kz,kw)

!-----------------------------------------------------------------------------!
!     ... input/output                                                        !
!-----------------------------------------------------------------------------!
      integer, intent(inout) :: j

!-----------------------------------------------------------------------------!
!     ... local                                                               !
!-----------------------------------------------------------------------------!
      integer kdata
      parameter(kdata=300)
      integer i, iw, n, nro, nra, idum, ierr, iz
      real xro(kdata), x1(kdata), yro(kdata), yr(kdata), yra(kdata)
      real a1(kdata), a2(kdata)
      real xb(kdata), yb(kdata)
      real yg(kw),yg1(kw), yg_ro(kz,kw),  yg_ra(kz,kw), ycomb(kz,kw)
      real tin(kz)
      real qy

      tin(:) = tlev(:)

!----------------------------------------------
!     ... jlabel(j)
!----------------------------------------------
      j = j+1
      jlabel(j) = 'CH3I + hv -> I'

!----------------------------------------------------
!     ... cross sections
!----------------------------------------------------
      open(kin,file=TRIM(pn)//'XS_CH3I_JPL10.txt',status='old')

      read(kin,*) idum, nro
      do i = 1, idum-2
        read(kin,*)
      enddo

      do i = 1, nro
        read(kin,*) xro(i), yro(i)
      enddo
      close(kin)

!----------------------------------------------------
!     ... Check routine 
!      do iw = 1, nro
!        print*, iw, xro(iw), yro(iw)
!      enddo
!      stop
!----------------------------------------------------
!     ... READ T-dependence (Roehl)
!----------------------------------------------------
      open(kin,file=TRIM(pn)//'XS_CH3I_td_A_JPL10.txt',status='old')

      read(kin,*) idum, nro
      do i = 1, idum-2
        read(kin,*)
      enddo

      do i = 1, nro
        read(kin,*) xro(i), a1(i), a2(i)
      enddo
      close(kin)
      
      a1(:) = a1(:) * 1.0e-3
      a2(:) = a2(:) * 1.0e-5
!----------------------------------------------------
!     ... Derive T-dep XS (Roehl) - Interp to Grid
!----------------------------------------------------
      do iz = 1, nz

!...  T (210-298K)
        IF ( (tin(iz) .GE. 210.0) .AND. (tin(iz) .LE. 298.0) ) THEN
          do iw = 1, nro
            yr(iw) = yro(iw) *(1 + a1(iw)*  (tin(iz)-298) 
     $                         + a2(iw)*( (tin(iz)-298)**2 ) )
          enddo
        ENDIF
!... T < 210K
        IF (tin(iz) .LT. 210.0) THEN
          do iw = 1, nro
            yr(iw) = yro(iw) *(1 + a1(iw)*  (210.0-298) 
     $                         + a2(iw)*( (210.0-298)**2 ) )
          enddo
        ENDIF
!... T > 298K
        IF (tin(iz) .GT. 298.0) THEN
          do iw = 1, nro
            yr(iw) = yro(iw) 
          enddo
        ENDIF

        x1(:) = xro(:)
        n     = nro
        call addpnt(x1,yr,kdata,n,x1(1)*(1.-deltax),0.)
        call addpnt(x1,yr,kdata,n,          0.,0.)
        call addpnt(x1,yr,kdata,n,x1(n)*(1.+deltax),0.)
        call addpnt(x1,yr,kdata,n,        1e38,0.)
      
        call inter2(nw,wl,yg,n,x1,yr,ierr)
        if (ierr .ne. 0) then
          write(*,*) ierr, jlabel(j)
          stop
        endif

        yg_ro(iz,:) = yg(:)
   
      enddo

!--------------------------------------------------    
!       iz = 1      
!       do iw = 38, 100
!         print*, iw, wc(iw), yg_ro(iz,iw), tin(iz)
!       enddo
!       stop
!----------------------------------------------------
!     ... READ T-dependence (Rattigan)
!----------------------------------------------------
      open(kin,file=TRIM(pn)//'XS_CH3I_td_B_JPL10.txt',status='old')

      read(kin,*) idum, nra
      do i = 1, idum-2
        read(kin,*)
      enddo

      do i = 1, nra
        read(kin,*) xb(i), yb(i)
!        print*, xb(i), yb(i)
      enddo
      close(kin)
      
      yb(:) = yb(:)*1e-3

      do iz = 1, nz

!     NOTE nro = 6 is 235nm (first T-dep for Rattigan)
!... T (243-333K)
        IF ( (tin(iz) .GE. 243.0) .AND. (tin(iz) .LE. 333.0) ) THEN
          iw = 1
          do i = 6, nro
            yra(iw) = exp(log(yro(i)) + yb(iw)*(tin(iz)-298.))
            iw = iw + 1
          enddo
        ENDIF
!... T <243K
        IF (tin(iz) .LT. 243.0) THEN
          iw = 1
          do i = 6, nro
            yra(iw) = exp(log(yro(i)) + yb(iw)*(243.-298.))
            iw = iw + 1
          enddo
        ENDIF
!... T >333K
        IF (tin(iz) .GT. 333.0) THEN
          iw = 1
          do i = 6, nro
            yra(iw) = exp(log(yro(i)) + yb(iw)*(333.-298.))
            iw = iw + 1
          enddo
        ENDIF

        x1(:) = xb(:)
        n     = nra
        call addpnt(x1,yra,kdata,n,x1(1)*(1.-deltax),0.)
        call addpnt(x1,yra,kdata,n,          0.,0.)
        call addpnt(x1,yra,kdata,n,x1(n)*(1.+deltax),0.)
        call addpnt(x1,yra,kdata,n,        1e38,0.)
      
        call inter2(nw,wl,yg1,n,x1,yra,ierr)
        if (ierr .ne. 0) then
          write(*,*) ierr, jlabel(j)
          stop
        endif

        yg_ra(iz,:) = yg1(:)
   
      enddo
!--------------------------------------------------    
!       iz = 1      
!       do iw = 38, 100
!         print*, iw, wc(iw), yg_ra(iz,iw), tin(iz)
!       enddo
!       stop
!--------------------------------------------------  

!-------------------------------------------------------
!     ...Combine cross sections  (grid new)
!        Roehl    (210-298K; 209.5-367.6nm)
!        Rattigan (243-333K; 236.5-367.5nm)
!-------------------------------------------------------
      do iz = 1, nz

!...   Set Roehl first         
        do iw = 1, nw
          ycomb(iz,iw) = yg_ro(iz,iw)
        enddo

!...   Set Rattigan
        IF (tin(iz) .GT. 298.) THEN
!....     iw = 48 is 236.5nm
          do iw = 48, nw
            ycomb(iz,iw) = yg_ra(iz,iw)
          enddo          
        ENDIF

       enddo
!-------------------------------------------------------
!     ... quantum yield (assumed) to be unity 
!-------------------------------------------------------
      qy = 1.0

      do iw = 1, nw-1
        do iz = 1, nz
          sq(j,iz,iw) = qy * ycomb(iz,iw)
        enddo
      enddo

!-------------------------------------------------------
!     ... Check routine 
!      iz = 1
!      print*, tin(iz)
!      do iw =38, 100
!        print*, iw, wc(iw), sq(j,iz,iw), yg_ro(iz,iw), yg_ra(iz,iw)
!      enddo
!      stop
!-------------------------------------------------------
      end subroutine XSQY_CH3I
