      subroutine XSQY_CH4(nw,wl,wc,nz,tlev,airlev,j,sq,jlabel,pn)
!-----------------------------------------------------------------------------!
!   purpose:                                                                  !
!   provide product (cross section) x (quantum yield):                        !
!         qy1  ch4 + hv -> ch3 + h                                            !
!         qy2  ch4 + hv -> h2  + hcl                                          !
!         qy3  ch4 + hv -> 2h  + ch2                                          !
!         qy4  ch4 + hv -> h + h2 + ch2                                       !
!                                                                             !
!   cross section:                                                            !
!     77.3 -137.0 nm, ditchburn, r.w., proc. roy. soc. london, 229a, 44, 1955 !
!     95.19-130.60 nm, sun, h. and weissler, g. l., jcp 23, 1160, 1955.       !
!    138.0 -160.0 nm, mount, g. h. and moos, h. w., astrophys., j. (letters)  !
!                     224, 135, 1978.                                         !
!   quantum yield: are taken from brownsword, et al., chem. phys. lett., 266  !
!                     259-266, 1997.                                          !
!     where the qy's are derived only at the lyman alpha wavelength           !
!                                                                             !
!            qy1  ch4 + hv -> ch3 + h        equals 0.39                      !                                  !
!            qy2  ch4 + hv -> h2  + hcl      equals 0.52                      !
!            qy3  ch4 + hv -> 2h  + ch2      equals 0.01                      !
!            qy4  ch4 + hv -> h + h2 + ch2   equals 0.08                      ! 
!-----------------------------------------------------------------------------!
!   parameters:                                                               !
!   nw     - integer, number of specified intervals + 1 in working        (i) !
!            wavelength grid                                                  !
!   wl     - real, vector of lower limits of wavelength intervals in      (i) !
!            working wavelength grid                                          !
!   wc     - real, vector of center points of wavelength intervals in     (i) !
!            working wavelength grid                                          !
!   nz     - integer, number of altitude levels in working altitude grid  (i) !
!   tlev   - real, temperature (k) at each specified altitude level       (i) !
!   airlev - real, air density (molec/cc) at each altitude level          (i) !
!   j      - integer, counter for number of weighting functions defined  (io) !
!   sq     - real, cross section x quantum yield (cm^2) for each          (o) !
!            photolysis reaction defined, at each defined wavelength and      !
!            at each defined altitude level                                   !
!   jlabel - character*60, string identifier for each photolysis reaction (o) !
!            defined                                                          !
!-----------------------------------------------------------------------------!
!   edit history:                                                             !
!   08/01/01   original, dek addition                                         !
!-----------------------------------------------------------------------------!
      implicit none
      include 'params'

!-----------------------------------------------------------------------------!
!     ... input                                                               !
!-----------------------------------------------------------------------------!
      real, intent(in) :: wl(kw)
      real, intent(in) :: wc(kw)
      real, intent(in) :: tlev(kz)
      real, intent(in) :: airlev(kz)

      integer, intent(in) :: nz
      integer, intent(in) :: nw

      character*80, intent(in) ::  pn
      character*60, intent(out) :: jlabel(kj)
      real, intent(out) :: sq(kj,kz,kw)

!-----------------------------------------------------------------------------!
!     ... input/output                                                        !
!-----------------------------------------------------------------------------!
      integer, intent(inout) :: j

!-----------------------------------------------------------------------------!
!     ... local                                                               !
!-----------------------------------------------------------------------------!
      integer kdata
      parameter(kdata=200)
      integer i, iw, n, idum, ierr, iz
      real x1(kdata), y1(kdata)
      real yg(kw)
      real qy1, qy2, qy3, qy4

!----------------------------------------------
!     ... jlabel(j) = 'CH4 -> products'
!----------------------------------------------
      j = j+1
      jlabel(j) = 'CH4 + hv -> CH3O2 + H'

      j = j+1
      jlabel(j) = 'CH4 + hv -> H2 + Products'

!---------------------------------------------
!      j = j+1
!      jlabel(j) = 'ch4 + hv -> ch2 + 2h'
!      j = j+1
!      jlabel(j) = 'ch4 + hv -> ch + h + h2'
!----------------------------------------------
!     ....cross sections (see above) 
!----------------------------------------------
      open(kin,file=TRIM(pn)//'XS_CH4.txt',status='old')
      read(kin,*) idum, n
      do i = 1, idum-2
        read(kin,*)
      enddo
      do i = 1, n
        read(kin,*) x1(i), y1(i)
      enddo
      close(kin)

      call addpnt(x1,y1,kdata,n,x1(1)*(1.-deltax),0.)
      call addpnt(x1,y1,kdata,n,          0.,0.)
      call addpnt(x1,y1,kdata,n,x1(n)*(1.+deltax),0.)
      call addpnt(x1,y1,kdata,n,        1e38,0.)
      call inter2(nw,wl,yg,n,x1,y1,ierr)
 
      if (ierr .ne. 0) then
        write(*,*) ierr, jlabel(j)
        stop
      endif

!-----------------------------------------------------
!     ... quantum yield for each branch (see ref above)
!-----------------------------------------------------
!        qy1 = 0.39
!        qy2 = 0.52
!        qy3 = 0.01
!	 qy4 = 0.08
!-----------------------------------------------------
        qy1 = 0.45
        qy2 = 0.55
	qy3 = 0.0
	qy4 = 0.0

!-------------------------------------------------
!     ... derive the cross section for each branch
!-------------------------------------------------
      do iw = 1, nw-1
        do iz = 1, nz
	   sq(j-1,iz,iw) = qy1 * yg(iw)
           sq(j,iz,iw)   = qy2 * yg(iw)
        enddo
      enddo

      end subroutine XSQY_CH4
