      subroutine XSQY_CL2(nw,wl,wc,nz,tlev,airlev,j,sq,jlabel,pn)
!-----------------------------------------------------------------------------!
!   purpose:                                                                  !
!   provide product (cross section) x (quantum yield) for cl2 photolysis:     !
!         Cl2 + hv -> 2 Cl                                                    !
!                                                                             !
!   cross section: JPL06  recommendation                                      !
!                                                                             !
!-----------------------------------------------------------------------------!
!   parameters:                                                               !
!   nw     - integer, number of specified intervals + 1 in working        (i) !
!            wavelength grid                                                  !
!   wl     - real, vector of lower limits of wavelength intervals in      (i) !
!            working wavelength grid                                          !
!   wc     - real, vector of center points of wavelength intervals in     (i) !
!            working wavelength grid                                          !
!   nz     - integer, number of altitude levels in working altitude grid  (i) !
!   tlev   - real, temperature (k) at each specified altitude level       (i) !
!   airlev - real, air density (molec/cc) at each altitude level          (i) !
!   j      - integer, counter for number of weighting functions defined  (io) !
!   sq     - real, cross section x quantum yield (cm^2) for each          (o) !
!            photolysis reaction defined, at each defined wavelength and      !
!            at each defined altitude level                                   !
!   jlabel - character*60, string identifier for each photolysis reaction (o) !
!            defined                                                          !
!-----------------------------------------------------------------------------!
!   edit history:                                                             !
!   Jan 16, 2008 - D. Kinnison                                                !
!-----------------------------------------------------------------------------!
      implicit none
      include 'params'

!-----------------------------------------------------------------------------!
!     ... input                                                               !
!-----------------------------------------------------------------------------!
      real, intent(in) :: wl(kw)
      real, intent(in) :: wc(kw)
      real, intent(in) :: tlev(kz)
      real, intent(in) :: airlev(kz)

      integer, intent(in) :: nz
      integer, intent(in) :: nw

      character*80, intent(in) ::  pn
      character*60, intent(out) :: jlabel(kj)
      real, intent(out) :: sq(kj,kz,kw)

!-----------------------------------------------------------------------------!
!     ... input/output                                                        !
!-----------------------------------------------------------------------------!
      integer, intent(inout) :: j

!-----------------------------------------------------------------------------!
!     ... local                                                               !
!-----------------------------------------------------------------------------!
      integer   kdata
      parameter(kdata=150)

      integer i, n, idum, nin
      integer iz, iw, n1
      integer ierr
      real xsave (kdata),    x1 (kdata), y1(kdata)
      real ytmp  (nz,kdata), ytd(nz,kw) 
      real yg    (kw),       yg1(kw),    tin(nz)
      real alpha, term1, term2, term3, qy

!----------------------------------------------
!     ... tin set to tlev
!----------------------------------------------           
      tin(:) = tlev(:)

!----------------------------------------------
!     ... jlabel(j) = 'Cl2 + hv -> 2Cl'
!----------------------------------------------
      j = j+1
      jlabel(j) = 'Cl2 + hv -> 2Cl'

!----------------------------------------------------
!     ... cross sections from JPL06 recommendation        
!----------------------------------------------------
      open(kin,file=TRIM(pn)//'XS_CL2_JPL06.txt',status='old')
      read(kin,*) idum, nin
      do i = 1, idum-2
        read(kin,*)
      enddo

      do i = 1, nin
        read(kin,*) xsave(i), y1(i)
!        print*, xsave(i), y1(i)
      enddo
      close(kin)

!...  Temperature Dependences 
      do iw = 1, nin
         do iz = 1, nz
           ytmp(iz,iw) = y1(iw)

           if ((tin(iz) .LT. 300.) .AND. (tin(iz) .GT. 195.)) then
              alpha = tanh (402.7/tin(iz))
              term1 = 27.3 *exp(-99.0*alpha*(ALOG (329.5/xsave(iw))**2))
              term2 = 0.932*exp(-91.5*alpha*(ALOG (406.5/xsave(iw))**2))
              term3 = alpha**0.5
              ytmp(iz,iw) = 1e-20*term3*(term1 + term2)
           endif

         enddo
      enddo
     
      do iz = 1, nz
        n     = nin
        x1(:) = xsave(:)
        y1(:) = ytmp(iz,:)
        call addpnt(x1,y1,kdata,n,x1(1)*(1.-deltax),0.)
        call addpnt(x1,y1,kdata,n,          0.,0.)
        call addpnt(x1,y1,kdata,n,x1(n)*(1.+deltax),0.)
        call addpnt(x1,y1,kdata,n,        1e38,0.)
        call inter2(nw,wl,yg,n,x1,y1,ierr)
        ytd(iz,:) = yg(:)

        if (ierr .ne. 0) then
           write(*,*) ierr, jlabel(j)
           stop
        endif

      enddo

!----------------------------------------------------------     
!       iz = 1 
!       print*, 'tin=', tin(iz)
!       do iw = 54, 100
!         print*, iw, wc(iw), yg(iw), ytd(iz,iw),tin(iz)
!       enddo
!       stop
!----------------------------------------------------------  

!------------------------------------------------------
!     ... quantum yield = 1 
!------------------------------------------------------
      qy = 1.
      do iw = 1, nw-1
         do iz = 1, nz
            sq(j,iz,iw) = qy * ytd(iz,iw)
         enddo
      enddo
      
      end subroutine XSQY_CL2
