      subroutine XSQY_CLONO2(nw,wl,wc,nz,tlev,airlev,j,sq,jlabel,pn)
!-----------------------------------------------------------------------------!
!   purpose:                                                                  !
!   provide product (cross section) x (quantum yield) for clono2 photolysis:  !
!         clono2 + hv -> products                                             !
!                                                                             !
!   cross section: JPL06  recommendation                                      !
!   quantum yield: JPL06  recommendation                                      !
!-----------------------------------------------------------------------------!
!   parameters:                                                               !
!   nw     - integer, number of specified intervals + 1 in working        (i) !
!            wavelength grid                                                  !
!   wl     - real, vector of lower limits of wavelength intervals in      (i) !
!            working wavelength grid                                          !
!   wc     - real, vector of center points of wavelength intervals in     (i) !
!            working wavelength grid                                          !
!   nz     - integer, number of altitude levels in working altitude grid  (i) !
!   tlev   - real, temperature (k) at each specified altitude level       (i) !
!   airlev - real, air density (molec/cc) at each altitude level          (i) !
!   j      - integer, counter for number of weighting functions defined  (io) !
!   sq     - real, cross section x quantum yield (cm^2) for each          (o) !
!            photolysis reaction defined, at each defined wavelength and      !
!            at each defined altitude level                                   !
!   jlabel - character*60, string identifier for each photolysis reaction (o) !
!            defined                                                          !
!-----------------------------------------------------------------------------!
!   edit history:                                                             !
!   01/15/06 Doug Kinnison                                                    !
!-----------------------------------------------------------------------------!
      implicit none
      include 'params'

!-----------------------------------------------------------------------------!
!     ... input                                                               !
!-----------------------------------------------------------------------------!
      real, intent(in) :: wl(kw)
      real, intent(in) :: wc(kw)
      real, intent(in) :: tlev(kz)
      real, intent(in) :: airlev(kz)

      integer, intent(in) :: nz
      integer, intent(in) :: nw

      character*80, intent(in) ::  pn
      character*60, intent(out) :: jlabel(kj)
      real, intent(out) :: sq(kj,kz,kw)

!-----------------------------------------------------------------------------!
!     ... input/output                                                        !
!-----------------------------------------------------------------------------!
      integer, intent(inout) :: j

!-----------------------------------------------------------------------------!
!     ... local                                                               !
!-----------------------------------------------------------------------------!
      integer kdata
      parameter(kdata=150)
      integer i, iw, n, idum, ierr, iz
      integer n1, n2, n3
      real x1 (kdata),x2(kdata),x3(kdata)
      real y1 (kdata),y2(kdata),y3(kdata)
      real yg1(kw),  yg2(kw),  yg3(kw)
      real tin(kz)
      real qy1, qy2, xs
!----------------------------------------------
!     ... tin set to tlev
!----------------------------------------------      
      tin(:) = tlev(:)

!----------------------------------------------
!     ... jlabel(j) = 'ClONO2 + hv  -> Cl + NO3'
!----------------------------------------------
      j = j+1
      jlabel(j) = 'ClONO2 + hv  -> Cl + NO3'

!----------------------------------------------------
!     ... cross sections from JPL06 recommendation
!----------------------------------------------------
      open(kin,
     &     file=TRIM(pn)//'XS_CLONO2_JPL06.txt',status='old')

      read(kin,*) idum, n
      do i = 1, idum-2
        read(kin,*)
      enddo

      do i = 1, n
        read(kin,*) x1(i), y1(i), y2(i), y3(i)
        y1(i) = y1(i) * 1e-20
        x2(i) = x1(i)
        x3(i) = x1(i)
      enddo
      close(kin)

      n1 = n
      call addpnt(x1,y1,kdata,n1,x1(1)*(1.-deltax),0.)
      call addpnt(x1,y1,kdata,n1,          0.,0.)
      call addpnt(x1,y1,kdata,n1,x1(n1)*(1.+deltax),0.)
      call addpnt(x1,y1,kdata,n1,        1e38,0.)
      call inter2(nw,wl,yg1,n1,x1,y1,ierr)
      if (ierr .ne. 0) then
         write(*,*) ierr, jlabel(j)
         stop
      endif

      n2 = n
      call addpnt(x2,y2,kdata,n2,x2(1)*(1.-deltax),0.)
      call addpnt(x2,y2,kdata,n2,          0.,0.)
      call addpnt(x2,y2,kdata,n2,x2(n2)*(1.+deltax),0.)
      call addpnt(x2,y2,kdata,n2,        1e38,0.)
      call inter2(nw,wl,yg2,n2,x2,y2,ierr)
      if (ierr .ne. 0) then
         write(*,*) ierr, jlabel(j)
         stop
      endif

      n3 = n
      call addpnt(x3,y3,kdata,n3,x3(1)*(1.-deltax),0.)
      call addpnt(x3,y3,kdata,n3,          0.,0.)
      call addpnt(x3,y3,kdata,n3,x3(n3)*(1.+deltax),0.)
      call addpnt(x3,y3,kdata,n3,        1e38,0.)
      call inter2(nw,wl,yg3,n3,x3,y3,ierr)
      if (ierr .ne. 0) then
         write(*,*) ierr, jlabel(j)
         stop
      endif

      do iw = 1, nw-1
!-------------------------------------
!     ... quantum yields (from JPL06)
!-------------------------------------
         if( wc(iw) .lt. 308.) then
            qy1 = 0.6
         elseif( (wc(iw) .ge. 308) .and. (wc(iw) .le. 364.) ) then
            qy1 = 7.143e-3 * wc(iw) - 1.6
         elseif( wc(iw) .gt. 364. ) then
            qy1 = 1.0
         endif
         qy2 = 1. - qy1

!--------------------------------------------         
!     ...compute t-dependent cross section
!--------------------------------------------
         do iz = 1, nz
            xs = yg1(iw)*( 1. + 
     $           yg2(iw)*(tin(iz)-296) + 
     $           yg3(iw)*(tin(iz)-296)*(tin(iz)-296))
            sq(j,iz,iw)   = qy1 * xs
            sq(j+1,iz,iw) = qy2 * xs

         enddo
      enddo
!-------------------------------------------------------
!     ... Check routine
!      iz = 1
!      do iw = 30, 87
!        print*, wc(iw), sq(j,iz,iw), sq(j+1,iz,iw), 
!     $           sq(j,iz,iw)+sq(j+1,iz,iw)
!      enddo
!      stop
!-------------------------------------------------------
      j = j+1
      jlabel(j) = 'ClONO2 + hv -> ClO + NO2'

      end subroutine XSQY_CLONO2
