      subroutine XSQY_H2O2(nw,wl,wc,nz,tlev,airlev,j,sq,jlabel,pn)
!-----------------------------------------------------------------------------!
!   purpose:                                                                  !
!   provide product of (cross section) x (quantum yield) for h2o2 photolysis  !
!          H2O2 + hv -> 2 OH                                                  !
!   cross section:  from JPL06                                                !
!   quantum yield:  assumed to be unity                                       !
!-----------------------------------------------------------------------------!
!   parameters:                                                               !
!   nw     - integer, number of specified intervals + 1 in working        (i) !
!            wavelength grid                                                  !
!   wl     - real, vector of lower limits of wavelength intervals in      (i) !
!            working wavelength grid                                          !
!   wc     - real, vector of center points of wavelength intervals in     (i) !
!            working wavelength grid                                          !
!   nz     - integer, number of altitude levels in working altitude grid  (i) !
!   tlev   - real, temperature (k) at each specified altitude level       (i) !
!   airlev - real, air density (molec/cc) at each altitude level          (i) !
!   j      - integer, counter for number of weighting functions defined  (io) !
!   sq     - real, cross section x quantum yield (cm^2) for each          (o) !
!            photolysis reaction defined, at each defined wavelength and      !
!            at each defined altitude level                                   !
!   jlabel - character*60, string identifier for each photolysis reaction (o) !
!            defined                                                          !
!-----------------------------------------------------------------------------!
!   edit history:                                                             !
!   02/21/08 Doug Kinnison                                                    !
!-----------------------------------------------------------------------------!
      implicit none
      include 'params'

!-----------------------------------------------------------------------------!
!     ... input                                                               !
!-----------------------------------------------------------------------------!
      real, intent(in) :: wl(kw)
	real, intent(in) :: wc(kw)
      real, intent(in) :: tlev(kz)
      real, intent(in) :: airlev(kz)

      integer, intent(in) :: nz
      integer, intent(in) :: nw

      character*80, intent(in) ::  pn
      character*60, intent(out) :: jlabel(kj)
      real, intent(out) :: sq(kj,kz,kw)

!-----------------------------------------------------------------------------!
!     ... input/output                                                        !
!-----------------------------------------------------------------------------!
      integer, intent(inout) :: j

!-----------------------------------------------------------------------------!
!     ... local                                                               !
!-----------------------------------------------------------------------------!
      integer kdata
      parameter(kdata=100)
      integer i, iw, n, idum
      integer ierr
      real x1(kdata), y1(kdata)
      real yg(kw),    tin(nz)
      real qy
      real a0, a1, a2, a3, a4, a5, a6, a7
      real b0, b1, b2, b3, b4
      real xs, t, lambda
      real suma, sumb, chi

!----------------------------------------------
!     ... tin set to tlev
!----------------------------------------------
      tin(:) = tlev(:) 

!----------------------------------------------
!     ... jlabel(j) = 'H2O2 -> 2OH
!----------------------------------------------
      j = j + 1
      jlabel(j) = 'H2O2 + hv  -> 2OH'

!----------------------------------------------------------
!     ... cross section from JPL06
!         tabulated data up to 260 nm
!----------------------------------------------------------
      open(unit=kin,
     &     file=TRIM(pn)//'XS_H2O2_JPL06.txt',status='old')
      read(kin,*) idum,n
      do i = 1, idum-2
         read(kin,*)
      enddo
      do i = 1, n
         read(kin,*) x1(i), y1(i)
         y1(i) = y1(i) * 1.e-20
      enddo
      close (kin)

      call addpnt(x1,y1,kdata,n,x1(1)*(1.-deltax),0.)
      call addpnt(x1,y1,kdata,n,               0.,0.)
      call addpnt(x1,y1,kdata,n,x1(n)*(1.+deltax),0.)
      call addpnt(x1,y1,kdata,n,           1.e+38,0.)
      call inter2(nw,wl,yg,n,x1,y1,ierr)
      if (ierr .ne. 0) then
         write(*,*) ierr, jlabel(j)
         stop
      endif

      a0 = 6.4761e+04            
      a1 = -9.2170972e+02        
      a2 = 4.535649              
      a3 = -4.4589016e-03        
      a4 = -4.035101e-05         
      a5 = 1.6878206e-07
      a6 = -2.652014e-10
      a7 = 1.5534675e-13

      b0 = 6.8123e+03
      b1 = -5.1351e+01
      b2 = 1.1522e-01
      b3 = -3.0493e-05
      b4 = -1.0924e-07

!---------------------------------
!     ... quantum yield = 1
!---------------------------------
      qy = 1.

      do iw = 1, nw - 1
!-------------------------------------
!     ... parameterization (jpl94)
!         range 260-350 nm; 200-400 k
!-------------------------------------

         if ((wl(iw) .ge. 260.) .and. (wl(iw) .lt. 350.)) then

           lambda = wc(iw)
           suma = ((((((a7*lambda + a6)*lambda + a5)*lambda + 
     >                  a4)*lambda +a3)*lambda + a2)*lambda + 
     >                  a1)*lambda + a0
           sumb = (((b4*lambda + b3)*lambda + b2)*lambda + 
     >               b1)*lambda + b0

           do i = 1, nz
              t = min(max(tin(i),200.),400.)       
              chi = 1./(1.+exp(-1265./t))
              xs = (chi * suma + (1.-chi)*sumb)*1e-21
              sq(j,i,iw) = xs*qy
           enddo
         else
           do i = 1, nz
              sq(j,i,iw) = yg(iw)*qy
           enddo
         endif

      enddo
      end subroutine XSQY_H2O2
