      subroutine XSQY_HO2(nw,wl,wc,nz,tlev,airlev,j,sq,jlabel,pn)
!-----------------------------------------------------------------------------!
!   PURPOSE:                                                                  !
!   Provide product (cross section) x (quantum yield) for HO2 photolysis:     !
!           HO2 + hv -> OH + O                                                !
!   Cross section: from JPL 906 recommendation                                !
!-----------------------------------------------------------------------------!
!   PARAMETERS:                                                               !
!   NW     - INTEGER, number of specified intervals + 1 in working        (I) !
!            wavelength grid                                                  !
!   WL     - REAL, vector of lower limits of wavelength intervals in      (I) !
!            working wavelength grid                                          !
!   WC     - REAL, vector of center points of wavelength intervals in     (I) !
!            working wavelength grid                                          !
!   NZ     - INTEGER, number of altitude levels in working altitude grid  (I) !
!   TLEV   - REAL, temperature (K) at each specified altitude level       (I) !
!   AIRLEV - REAL, air density (molec/cc) at each altitude level          (I) !
!   J      - INTEGER, counter for number of weighting functions defined  (IO) !
!   SQ     - REAL, cross section x quantum yield (cm^2) for each          (O) !
!            photolysis reaction defined, at each defined wavelength and      !
!            at each defined altitude level                                   !
!   JLABEL - character*60, string identifier for each photolysis reaction (O) !
!            defined                                                          !
!-----------------------------------------------------------------------------!
!   EDIT HISTORY:                                                             !
!   02/06/08 Doug Kinnison                                                    !
!-----------------------------------------------------------------------------!
      implicit none
      include 'params'

!-----------------------------------------------------------------------------!
!     ... input                                                               !
!-----------------------------------------------------------------------------!
      real, intent(in) :: wl(kw)
      real, intent(in) :: wc(kw)
      real, intent(in) :: tlev(kz)
      real, intent(in) :: airlev(kz)

      integer, intent(in) :: nz
      integer, intent(in) :: nw

      character*80, intent(in) ::  pn
      character*60, intent(out) :: jlabel(kj)
      real, intent(out) :: sq(kj,kz,kw)

!-----------------------------------------------------------------------------!
!     ... input/output                                                        !
!-----------------------------------------------------------------------------!
      integer, intent(inout) :: j

!-----------------------------------------------------------------------------!
!     ... local                                                               !
!-----------------------------------------------------------------------------!
      integer kdata
      parameter(kdata=100)
      integer i, iw, n, idum, ierr, iz
      real x1(kdata)
      real y1(kdata)
      real yg(kw)
      real qy(kw)

!----------------------------------------------
!     ... jlabel(j) = 'HO2 + hv -> OH + O'
!----------------------------------------------
      j = j+1
      jlabel(j) = 'HO2 + hv -> OH + O'

!--------------------------------------------------
!     ...cross sections from JPL06 recommendation 
!--------------------------------------------------
      open(kin,file=TRIM(pn)//'XS_HO2_JPL06.txt',status='old')
      read(kin,*) idum, n
      do i = 1, idum-2
        read(kin,*)
      enddo
      do i = 1, n
        read(kin,*) x1(i), y1(i)
        y1(i) = y1(i) * 1e-20
      enddo
      close(kin)

      call addpnt(x1,y1,kdata,n,x1(1)*(1.-deltax),0.)
      call addpnt(x1,y1,kdata,n,          0.,0.)
      call addpnt(x1,y1,kdata,n,x1(n)*(1.+deltax),0.)
      call addpnt(x1,y1,kdata,n,        1e38,0.)

      call inter2(nw,wl,yg,n,x1,y1,ierr)
  
      if (ierr .ne. 0) then
        write(*,*) ierr, jlabel(j)
        stop
      endif
!--------------------------------------------------------------
!     ... Quantum yield:  
!         absolute quantum yield has not been reported yet, but
!         Lee measured a quantum yield for o(1d) production at 
!         248nm that was 15 time larger than at 193 nm
!         here:  
!           a quantum yield of unity is assumed at 248 nm and 
!           beyond, for shorter wavelengths a linear decrease 
!           with lambda is assumed
!--------------------------------------------------------------
      do iw = 1, nw-1
         if (wc(iw) .ge. 248.) then
            qy(iw) = 1.
         else
            qy(iw) = 1./15. + (wc(iw)-193.)*(14./15.)/(248.-193.)
            qy(iw) = max(qy(iw),0.)
         endif

         do iz = 1, nz
           sq(j,iz,iw) = qy(iw) * yg(iw)
         enddo
      enddo

!----------------------------------------------     
!       iz = 1 
!       do iw = 15, 77
!         print*, iw, wc(iw), yg(iw), qy(iw)
!       enddo
!       stop
!----------------------------------------------     
      end subroutine XSQY_HO2
