      SUBROUTINE XSQY_HYAC(nw,wl,wc,nz,tlev,airden,j,sq,jlabel,pn)
!---------------------------------------------------------------------------!
!  PURPOSE:                                                                 !
!  Provide the product (cross section) x (quantum yield) for hydroxyacetone !
!  CH2(OH)COCH3        photolysis:                                          !
!           CH2(OH)COCH3  -> CH3CO + CH2OH
!                         -> CH2(OH)CO + CH3                                !
!                                                                           !
!  Cross section from Orlando et al. (1999)                                 !
!                                                                           !
!  Quantum yield assumed 0.325 for each channel (J. Orlando, priv.comm.2003)!
!---------------------------------------------------------------------------!
!  PARAMETERS:                                                              !
!  NW     - INTEGER, number of specified intervals + 1 in working        (I)!
!           wavelength grid                                                 !
!  WL     - REAL, vector of lower limits of wavelength intervals in      (I)!
!           working wavelength grid                                         !
!  WC     - REAL, vector of center points of wavelength intervals in     (I)!
!           working wavelength grid                                         !
!  NZ     - INTEGER, number of altitude levels in working altitude grid  (I)!
!  TLEV   - REAL, temperature (K) at each specified altitude level       (I)!
!  AIRDEN - REAL, air density (molec/cc) at each altitude level          (I)!
!  J      - INTEGER, counter for number of weighting functions defined  (IO)!
!  SQ     - REAL, cross section x quantum yield (cm^2) for each          (O)!
!           photolysis reaction defined, at each defined wavelength and     !
!           at each defined altitude level                                  !
!  JLABEL - CHARACTER*50, string identifier for each photolysis reaction (O)!
!           defined                                                         !
!---------------------------------------------------------------------------!
      IMPLICIT NONE
      INCLUDE 'params'

!---------------------------------------------------------------------------!
!     ... input                                                             !
!---------------------------------------------------------------------------!
      real, intent(in) :: wl(kw)
      real, intent(in) :: wc(kw)
      real, intent(in) :: tlev(kz)
      real, intent(in) :: airden(kz)

      integer, intent(in) :: nz
      integer, intent(in) :: nw

      character*80, intent(in) ::  pn
      character*60, intent(out) :: jlabel(kj)
      real, intent(out) :: sq(kj,kz,kw)

!---------------------------------------------------------------------------!
!     ... input/output                                                      !
!---------------------------------------------------------------------------!
      integer, intent(inout) :: j

!---------------------------------------------------------------------------!
!     ... local                                                             !
!---------------------------------------------------------------------------!
      integer kdata
      parameter(kdata=20000)
      integer i, n, ierr, iz, iw
      real  x(kdata), y(kdata)
      real  yg(kw)
      real  qy

!----------------------------------------------------
!     ... CH2(OH)COCH3 photolysis
!         from Orlando et al. 1999
!----------------------------------------------------
!      j = j+1
!      jlabel(j) = 'CH2(OH)COCH3 -> CH3CO + CH2(OH)'
!      j = j+1
!      jlabel(j) = 'CH2(OH)COCH3 -> CH2(OH)CO + CH3'
!
!      ... MODEL has one combined branch
       j = j + 1
       jlabel(j) = 'HYAC + hv -> CH3CO3 + HO2 + CH2O'

!----------------------------------------------------
!     ... cross sections
!----------------------------------------------------
      OPEN(UNIT=kin,FILE=TRIM(pn)//'XS_HYAC.txt',
     $     STATUS='old')
      DO i = 1, 8
         READ(kin,*)
      ENDDO
      n = 101
      DO i = 1, n
         READ(kin,*) x(i), y(i)
         y(i) = y(i)
      ENDDO
      CLOSE(kin)

      CALL addpnt(x,y,kdata,n,x(1)*(1.-deltax),0.)
      CALL addpnt(x,y,kdata,n,               0.,0.)
      CALL addpnt(x,y,kdata,n,x(n)*(1.+deltax),0.)
      CALL addpnt(x,y,kdata,n,           1.e+38,0.)
      CALL inter2(nw,wl,yg,n,x,y,ierr)
      IF (ierr .NE. 0) THEN
         WRITE(*,*) ierr, jlabel(j)
         STOP
      ENDIF

!----------------------------------------------------
!     ... Quantum yield
!----------------------------------------------------
!          Total quantum yield  = 0.65, equal for 
!          each of the two channels
!----------------------------------------------------
      qy = 0.65

      DO iw = 1, nw - 1
         DO i = 1, nz
            sq(j,i,iw) = yg(iw) * qy
         ENDDO
      ENDDO

      end subroutine XSQY_HYAC
