      SUBROUTINE XSQY_MGLY(nw,wl,wc,nz,tlev,airden,j,sq,jlabel,pn)
!---------------------------------------------------------------------------!
!  PURPOSE:                                                                 !
!  Provide the product (cross section) x (quantum yield) for CH3COCHO       !
!  photolysis:                                                              !
!           MGLY (CH3COCHO) + hv -> CH3CO + HCO                             !
!                                                                           !
!  Cross section:                                                           !
!                Average at 1 nm of Staffelbach et al., 1995, and           !
!                      Meller et al., 1991                                  !
!  Quantum yield:                                                           !
!                 Chen, Y., W. Wang, and L. Zhu, Wavelength-dependent       !
!                 photolysis of methylglyoxal in the 290-440 nm region,     !
!                 J Phys Chem A, 104, 11126-11131, 2000.                    !
!---------------------------------------------------------------------------!
!  PARAMETERS:                                                              !
!  NW     - INTEGER, number of specified intervals + 1 in working        (I)!
!           wavelength grid                                                 !
!  WL     - REAL, vector of lower limits of wavelength intervals in      (I)!
!           working wavelength grid                                         !
!  WC     - REAL, vector of center points of wavelength intervals in     (I)!
!           working wavelength grid                                         !
!  NZ     - INTEGER, number of altitude levels in working altitude grid  (I)!
!  TLEV   - REAL, temperature (K) at each specified altitude level       (I)!
!  AIRDEN - REAL, air density (molec/cc) at each altitude level          (I)!
!  J      - INTEGER, counter for number of weighting functions defined  (IO)!
!  SQ     - REAL, cross section x quantum yield (cm^2) for each          (O)!
!           photolysis reaction defined, at each defined wavelength and     !
!           at each defined altitude level                                  !
!  JLABEL - CHARACTER*50, string identifier for each photolysis reaction (O)!
!           defined                                                         !
!---------------------------------------------------------------------------!
      IMPLICIT NONE
      INCLUDE 'params'

!---------------------------------------------------------------------------!
!     ... input                                                             !
!---------------------------------------------------------------------------!
      real, intent(in) :: wl(kw)
      real, intent(in) :: wc(kw)
      real, intent(in) :: tlev(kz)
      real, intent(in) :: airden(kz)

      integer, intent(in) :: nz
      integer, intent(in) :: nw

      character*80, intent(in) ::  pn
      character*60, intent(out) :: jlabel(kj)
      real, intent(out) :: sq(kj,kz,kw)

!---------------------------------------------------------------------------!
!     ... input/output                                                      !
!---------------------------------------------------------------------------!
      integer, intent(inout) :: j

!---------------------------------------------------------------------------!
!     ... local                                                             !
!---------------------------------------------------------------------------!
      integer kdata
      parameter (kdata=500)

      integer  i, n, n1, n2, ierr, iw, iz
      real x1(kdata), x2(kdata)
      real y1(kdata), y2(kdata)
      real x (kdata), y(kdata)
      real yg(kw), yg1(kw), yg2(kw)
      real qy
      real sig
      real phi0, kq

!-------------------------------------------------------
!     ... jlabel(j) = 'MGLY + hv ->  CH3CO3  + CO + HO2'
!-------------------------------------------------------
      j = j+1
      jlabel(j) = 'MGLY + hv -> CH3CO3  + CO + HO2'

!----------------------------------------------------
!     ... cross sections 
!----------------------------------------------------
      OPEN(UNIT=kin,FILE=
     &   TRIM(pn)//'XS_CH3COCHO_ncar.txt',
     $        STATUS='old')
      n = 271
      DO i = 1, n
        READ(kin,*) x1(i), y1(i)
      ENDDO
      CLOSE(kin)

      CALL addpnt(x1,y1,kdata,n,x1(1)*(1.-deltax),0.)
      CALL addpnt(x1,y1,kdata,n,               0.,0.)
      CALL addpnt(x1,y1,kdata,n,x1(n)*(1.+deltax),0.)
      CALL addpnt(x1,y1,kdata,n,           1.e+38,0.)
      CALL inter2(nw,wl,yg,n,x1,y1,ierr)
      IF (ierr .NE. 0) THEN
         WRITE(*,*) ierr, jlabel(j)
         STOP
      ENDIF

!-------------------------------------------------------
!     ... combine qy * xs
!-------------------------------------------------------
      DO iw = 1, nw - 1

         sig = yg(iw)

         DO i = 1, nz

!----------------------------------------
!             quantum yields:
!             zero pressure yield:
!             1.0 for wc < 380 nm
!             0.0 for wc > 440 nm
!             linear in between:
!----------------------------------------
               phi0 = 1. - (wc(iw) - 380.)/60.
               phi0 = MIN(phi0,1.)
               phi0 = MAX(phi0,0.)

!----------------------------------------------------------
!              Pressure correction: 
!              quenching coefficient, torr-1
!              in air, Koch and Moortgat:
!----------------------------------------------------------
               kq = 1.36e8 * EXP(-8793/wc(iw))

!----------------------------------------------------------
!              In N2, Chen et al:
!----------------------------------------------------------
!              kq = 1.93e4 * EXP(-5639/wc(iw))

               IF(phi0 .GT. 0.) THEN
                  IF (wc(iw) .GE. 380. .AND. wc(iw) .LE. 440.) THEN
                     qy = phi0 / (phi0 + kq * airden(i) * 760./2.456E19)
                  ELSE
                     qy = phi0
                  ENDIF
               ELSE
                  qy = 0.
               ENDIF

               sq(j,i,iw) = sig * qy

         ENDDO
      ENDDO

      end subroutine XSQY_MGLY
