      SUBROUTINE XSQY_MVK(nw,wl,wc,nz,tlev,airden,j,sq,jlabel,pn)
!---------------------------------------------------------------------------!
!  PURPOSE:                                                                 !
!  Provide the product (cross section) x (quantum yield) for CH3COCHCH2     !
!  Methyl vinyl ketone photolysis:                                          !
!           CH3C(O)CH=CH2 + hv -> Products                                  !
!                                                                           !
!  Cross section from JPL06                                                 !
!                                                                           !
!---------------------------------------------------------------------------!
!  PARAMETERS:                                                              !
!  NW     - INTEGER, number of specified intervals + 1 in working        (I)!
!           wavelength grid                                                 !
!  WL     - REAL, vector of lower limits of wavelength intervals in      (I)!
!           working wavelength grid                                         !
!  WC     - REAL, vector of center points of wavelength intervals in     (I)!
!           working wavelength grid                                         !
!  NZ     - INTEGER, number of altitude levels in working altitude grid  (I)!
!  TLEV   - REAL, temperature (K) at each specified altitude level       (I)!
!  AIRDEN - REAL, air density (molec/cc) at each altitude level          (I)!
!  J      - INTEGER, counter for number of weighting functions defined  (IO)!
!  SQ     - REAL, cross section x quantum yield (cm^2) for each          (O)!
!           photolysis reaction defined, at each defined wavelength and     !
!           at each defined altitude level                                  !
!  JLABEL - f*50, string identifier for each photolysis reaction (O)!
!           defined                                                         !
!---------------------------------------------------------------------------!
      IMPLICIT NONE
      INCLUDE 'params'

!---------------------------------------------------------------------------!
!     ... input                                                             !
!---------------------------------------------------------------------------!
      real, intent(in) :: wl(kw)
      real, intent(in) :: wc(kw)
      real, intent(in) :: tlev(kz)
      real, intent(in) :: airden(kz)

      integer, intent(in) :: nz
      integer, intent(in) :: nw

      character*80, intent(in) ::  pn
      character*60, intent(out) :: jlabel(kj)
      real, intent(out) :: sq(kj,kz,kw)

!---------------------------------------------------------------------------!
!     ... input/output                                                      !
!---------------------------------------------------------------------------!
      integer, intent(inout) :: j

!---------------------------------------------------------------------------!
!     ... local                                                             !
!---------------------------------------------------------------------------!
      integer kdata
      parameter(kdata=300)
      integer i, n, ierr, iw, iz, idum
      real x1(kdata), y1(kdata)
      real yg(kw)
      real qy

!----------------------------------------------
!     ... jlabel(j) = 'CH3COCHCH2 + hv -> prod'
!----------------------------------------------
      j = j+1
      jlabel(j) = 'MVK + hv -> Products'

!----------------------------------------------------
!     ... cross sections from JPL06 recommendation
!----------------------------------------------------
      open(kin,file=TRIM(pn)//'XS_MVK_JPL06.txt',status='old')

      read(kin,*) idum, n
      do i = 1, idum-2
        read(kin,*)
      enddo

      do i = 1, n
        read(kin,*) x1(i), y1(i)
!       print*, x1(i), y1(i)
      enddo
      close(kin)
      
      call addpnt(x1,y1,kdata,n,x1(1)*(1.-deltax),0.)
      call addpnt(x1,y1,kdata,n,          0.,0.)
      call addpnt(x1,y1,kdata,n,x1(n)*(1.+deltax),0.)
      call addpnt(x1,y1,kdata,n,        1e38,0.)
      call inter2(nw,wl,yg,   n,x1,     y1,ierr)

      if (ierr .ne. 0) then
        write(*,*) ierr, jlabel(j)
        stop
      endif

!-------------------------------------------------------
!     ... Check Routine
!      do iw = 61, 87
!        print*, iw, wc(iw), yg(iw)
!      enddo
!      stop
!-------------------------------------------------------
!-------------------------------------------------------
!     ... quantum yield (assumed) to be unity (JPL06)
!-------------------------------------------------------
!         See Gierczak, et al.
!-------------------------------------------------------
      do iw = 1, nw - 1
         do iz = 1, nz
            qy = exp(-0.055*(wc(iw)-308.)) / 
     $           (5.5 + 9.2e-19*airden(iz))
            qy = min(qy, 1.)
            sq(j,iz,iw) = yg(iw) * qy
         enddo
      enddo

      end subroutine XSQY_MVK
