      subroutine XSQY_N2O(nw,wl,wc,nz,tlev,airlev,j,sq,jlabel,pn)
!-----------------------------------------------------------------------------!
!   PURPOSE:                                                                  !
!   Provide product (cross section) x (quantum yield) for N2O photolysis:     !
!               N2O + hv -> N2 + O(1D)                                        !
!   Cross section: from JPL06 recommendation                                  !
!   Quantum yield: assumed to be unity, based on Greenblatt and Ravishankara  !
!-----------------------------------------------------------------------------!
!   PARAMETERS:                                                               !
!   NW     - INTEGER, number of specified intervals + 1 in working        (I) !
!            wavelength grid                                                  !
!   WL     - REAL, vector of lower limits of wavelength intervals in      (I) !
!            working wavelength grid                                          !
!   WC     - REAL, vector of center points of wavelength intervals in     (I) !
!            working wavelength grid                                          !
!   NZ     - INTEGER, number of altitude levels in working altitude grid  (I) !
!   TLEV   - REAL, temperature (K) at each specified altitude level       (I) !
!   AIRLEV - REAL, air density (molec/cc) at each altitude level          (I) !
!   J      - INTEGER, counter for number of weighting functions defined  (IO) !
!   SQ     - REAL, cross section x quantum yield (cm^2) for each          (O) !
!            photolysis reaction defined, at each defined wavelength and      !
!            at each defined altitude level                                   !
!   JLABEL - character*60, string identifier for each photolysis reaction (O) !
!            defined                                                          !
!-----------------------------------------------------------------------------!
!   EDIT HISTORY:                                                             !
!   05/98  Original, adapted from former JSPEC1 subroutine                    !
!-----------------------------------------------------------------------------!
      implicit none
      include 'params'

!-----------------------------------------------------------------------------!
!     ... input                                                               !
!-----------------------------------------------------------------------------!
      real, intent(in) :: wl(kw)
      real, intent(in) :: wc(kw)
      real, intent(in) :: tlev(kz)
      real, intent(in) :: airlev(kz)

      integer, intent(in) :: nz
      integer, intent(in) :: nw
      character*80 pn
      character*60, intent(out) :: jlabel(kj)
      real, intent(out) :: sq(kj,kz,kw)

!-----------------------------------------------------------------------------!
!     ... input/output                                                        !
!-----------------------------------------------------------------------------!
      integer, intent(inout) :: j

!-----------------------------------------------------------------------------!
!     ... local                                                               !
!-----------------------------------------------------------------------------!
      integer kdata
      parameter  (kdata=100)
      integer i, iw, iz, n, idum, ierr
      real x1    (kdata)
      real y1    (kdata)
      real yg    (kw)
      real ytmp  (nz,kdata)
      real tin   (nz)
      real qy
      real a, b, c
      real a0, a1, a2, a3, a4
      real b0, b1, b2, b3
      real t, lambda

!--------------------------------------
!     ... Set tin
!--------------------------------------      
      tin(:) = tlev(:)

!--------------------------------------
!     ... jlabel(j) N2O -> N2 + O(1D)
!--------------------------------------
      j = j+1
      jlabel(j) = 'N2O + hv -> N2 + O(1D)'

!----------------------------------------------------
!     ... cross sections from JPL06 recommendation
!----------------------------------------------------
      open(kin,file=TRIM(pn)//'XS_N2O_JPL06.txt',status='old')

      read(kin,*) idum, n
      do i = 1, idum-2
        read(kin,*)
      enddo

      do i = 1, n
        read(kin,*) x1(i), y1(i)
      enddo
      close(kin)
      
      call addpnt(x1,y1,kdata,n,x1(1)*(1.-deltax),0.)
      call addpnt(x1,y1,kdata,n,          0.,0.)
      call addpnt(x1,y1,kdata,n,x1(n)*(1.+deltax),0.)
      call addpnt(x1,y1,kdata,n,        1e38,0.)

      call inter2(nw,wl,yg,n,x1,y1,ierr)

      if (ierr .ne. 0) then
        write(*,*) ierr, jlabel(j)
        stop
      endif

!------------------------------------------------------------------
!     ... cross sections according to JPL06 (identical to 94 rec.)
!------------------------------------------------------------------
      A0 = 68.21023                
      A1 = -4.071805               
      A2 = 4.301146E-02            
      A3 = -1.777846E-04           
      A4 = 2.520672E-07

      B0 = 123.4014
      B1 = -2.116255
      B2 = 1.111572E-02
      B3 = -1.881058E-05

      ytmp(:,:) = 0.0

!-------------------------------------------------------------------
!     ... quantum yield of N(4s) and NO(2Pi) is less than 1% 
!         (Greenblatt and Ravishankara), so quantum yield of O(1D) 
!         is assumed to be unity
!-------------------------------------------------------------------
!     temperature dependences: 173nm-240nm; 194K and 302K.
      DO iw = 1, nw-1
         lambda = wc(iw)   
         IF (lambda .GE. 173. .AND. lambda .LE. 240.) THEN
           DO iz = 1, nz
	      
             t = MAX(194.,MIN(tin(iz),302.))

             A = (((A4*lambda+A3)*lambda+A2)*lambda+A1)*lambda+A0
             B = (((B3*lambda+B2)*lambda+B1)*lambda+B0)
             B = (t-300.)*EXP(B)
             ytmp(iz,iw) = EXP(A+B)

            IF (ytmp(iz,iw) .GT. 1e-10) THEN
               print*, "XS N2O=", ytmp(iz,iw)
               print*, "t =  ", t
               print*, "iw  =  ", iw, wc(iw)
               stop
            ENDIF

           ENDDO
         ENDIF
      ENDDO

!-----------------------------------------------------------
!     ... Combine cross sections
!     ... temp. dep and file XS are on same wavelength grid.
!-----------------------------------------------------------
      qy = 1
      DO iz = 1, nz

        DO iw = 1,nw-1

          IF (wc(iw) .LT.173.0) THEN 
            sq(j,iz,iw) = qy * yg(iw)
          ENDIF
          
          IF ( (wc(iw) .GE.173.0) .AND. (wc(iw) .LE. 240.) ) THEN
            IF (ytmp(iz,iw) .GT. 1e-10) THEN
               print*, "XS N2O=", ytmp(iz,iw)
               print*, "temp=  ", tin(iz)
               print*, "iw  =  ", iw, wc(iw)
               stop
            ENDIF
            sq(j,iz,iw) = qy * ytmp(iz,iw)
          ENDIF

        ENDDO

      ENDDO

!----------------------------------------------------------     
!       do iz = 1, nz
!       iz = 1
!       print*, 'nz=', iz
!       do iw = 14,55
!         print*, iw, wc(iw), sq(j,iz,iw), tin(iz)
!       enddo
!       enddo
!       stop
!----------------------------------------------------------         
      end subroutine XSQY_N2O
