      subroutine XSQY_NO2(nw,wl,wc,nz,tlev,airlev,j,sq,jlabel,pn)
!-----------------------------------------------------------------------------!
!   purpose:                                                                  !
!   provide the product (cross section) x (quantum yield) for no2             !
!   photolysis:                                                               !
!          NO2 + hv -> NO + O(3p)                                             !
!   cross section from JPL06                                                  !
!-----------------------------------------------------------------------------!
!   parameters:                                                               !
!   nw     - integer, number of specified intervals + 1 in working        (i) !
!            wavelength grid                                                  !
!   wl     - real, vector of lower limits of wavelength intervals in      (i) !
!            working wavelength grid                                          !
!   wc     - real, vector of center points of wavelength intervals in     (i) !
!            working wavelength grid                                          !
!   nz     - integer, number of altitude levels in working altitude grid  (i) !
!   tlev   - real, temperature (k) at each specified altitude level       (i) !
!   airlev - real, air density (molec/cc) at each altitude level          (i) !
!   j      - integer, counter for number of weighting functions defined  (io) !
!   sq     - real, cross section x quantum yield (cm^2) for each          (o) !
!            photolysis reaction defined, at each defined wavelength and      !
!            at each defined altitude level                                   !
!   jlabel - character*60, string identifier for each photolysis reaction (o) !
!            defined                                                          !
!-----------------------------------------------------------------------------!
!   edit history:                                                             !
!   02/04/08 Doug Kinnison                                                    !
!-----------------------------------------------------------------------------!
      implicit none
      include 'params'

!-----------------------------------------------------------------------------!
!     ... input                                                               !
!-----------------------------------------------------------------------------!
      real, intent(in) :: wl(kw)
      real, intent(in) :: wc(kw)
      real, intent(in) :: tlev(kz)
      real, intent(in) :: airlev(kz)

      integer, intent(in) :: nz
      integer, intent(in) :: nw
      character*80 pn
      character*60, intent(out) :: jlabel(kj)
      real, intent(out) :: sq(kj,kz,kw)

!-----------------------------------------------------------------------------!
!     ... input/output                                                        !
!-----------------------------------------------------------------------------!
      integer, intent(inout) :: j

!-----------------------------------------------------------------------------!
!     ... local                                                               !
!-----------------------------------------------------------------------------!
      integer, parameter :: kdata = 250
      integer i, iw, iz, n, n1, idum, ierr, iskip
      real x1   (kdata), y1   (kdata),    y2(kdata)
      real x220 (kdata), x220a(kdata), x220b(kdata), y220(kdata)
      real x294 (kdata), x294a(kdata), x294b(kdata), y294(kdata)
      real y220s(kdata), y294s(kdata)
      real xqy  (kdata), qy248(kdata), qy298(kdata)
      real yg220(kw),    yg294(kw)
      real yg248(kw),    yg298(kw)
      real xsno2(kz,kw), qyno2(kz,kw)
      real dum
      real tin(kz)

!----------------------------------------------
!     ... tin set to tlev
!----------------------------------------------      
      tin(:) = tlev(:)

!----------------------------------------------
!     ... jlabel(j) = 'NO2 -> NO + O'
!----------------------------------------------
      j = j + 1
      jlabel(j) = 'NO2 + hv -> NO + O(3P)'

!-----------------------------------------------------------
!     ... cross section data from JPL 06
!-----------------------------------------------------------
!... 220K
      open(unit=kin,
     &     file=TRIM(pn)//'XS_NO2_220K_JPL06.txt',status='old')

      read(kin,*) idum, n
      do i = 1, idum-2
        read(kin,*)
      enddo

      do i = 1, n
        read(kin,*) x220a(i), x220b(i), y220(i)
      enddo
      close(kin)

!... 294K
      open(unit=kin,
     &     file=TRIM(pn)//'XS_NO2_294K_JPL06.txt',status='old')

      read(kin,*) idum, n
      do i = 1, idum-2
        read(kin,*)
      enddo

      do i = 1, n
        read(kin,*) x294a(i), x294b(i), y294(i)
    
      enddo
      close(kin)

!---------------------------------------------------------------
!     ... Check routine 
!      do iw = 1, n
!        print*, iw, x220b(iw), x294b(iw), y220(iw), y294(iw)
!      enddo
!      stop
!---------------------------------------------------------------
!---------------------------------------------------------------
!      Data need to be scaled to total area
!      per bin so that they can be used with inter3
!---------------------------------------------------------------
      do i = 1, n
         y220s(i) = (x220b(i)-x220a(i)) * y220(i)
         y294s(i) = (x294b(i)-x294a(i)) * y294(i)
      enddo
      close(kin)

      x220a(n+1) = x220b(n)
      x294a(n+1) = x294a(n)

!      print*, "JNO2"
      call inter3(nw,wl,yg220,n,x220a,y220s,0)
      call inter3(nw,wl,yg294,n,x294a,y294s,0)
!      print*, "JNO2 line Aa"
!     ... yg220, yg294 are per nm, so rescale by bin widths
      do iw = 1, nw-1
         if ((wc(iw) .GE. 240.9) .AND. (wc(iw) .LE. 662.5)) THEN
           yg220(iw) = yg220(iw)/(wl(iw+1)-wl(iw))
           yg294(iw) = yg294(iw)/(wl(iw+1)-wl(iw))
         else
           yg220(iw) = 0.0
           yg294(iw) = 0.0
         endif
      enddo
!      print*, "JNO2 line A"
!-------------------------------------------------------
!     ... Check routine 
!      do iw = 1, nw-1
!        print*, iw, wc(iw), yg220(iw), yg294(iw)
!      enddo
!      stop
!-------------------------------------------------------
      do iw = 1, nw-1
         do iz = 1, nz
           xsno2(iz,iw) = yg220(iw)
           if ((tin(iz) .GE. 220.) .AND. (tin(iz) .le. 294.)) then
             xsno2(iz,iw) = yg220(iw) + 
     $                    (yg294(iw)-yg220(iw))/(294.- 220.) *
     $                    (tin(iz)-220.)
           endif
           if (tin(iz) .GT. 294.) then
             xsno2(iz,iw) = yg294(iw)
           endif
         enddo
      enddo
!      print*, "JNO line B"
!-------------------------------------------------------
!     ... Check routine 
!      iz = 1
!      do iw = 1, nw-1
!        print*, iw, wc(iw), xsno2(iz,iw), tin(iz)
!      enddo
!      stop
!-------------------------------------------------------
!-------------------------------------------------------
!     ... read in and derive qy
!-------------------------------------------------------
      open(unit=kin,
     &     file=TRIM(pn)//'QY_NO2_JPL06.txt',status='old')

      read(kin,*) idum, n1
      do i = 1, idum-2
        read(kin,*)
      enddo

      do i = 1, n1
        read(kin,*) xqy(i), qy298(i), qy248(i)
      enddo
      close(kin)
      
      x1(:) = xqy(:)
      y1(:) = qy248(:)
      n     = n1
      call addpnt(x1,y1,kdata,n,x1(1)*(1.-deltax),0.)
      call addpnt(x1,y1,kdata,n,          0.,0.)
      call addpnt(x1,y1,kdata,n,x1(n)*(1.+deltax),0.)
      call addpnt(x1,y1,kdata,n,        1e38,0.)
      call inter2(nw,wl,yg248,   n,x1,     y1,ierr)

      x1(:) = xqy(:)
      y1(:) = qy298(:)
      n     = n1
      call addpnt(x1,y1,kdata,n,x1(1)*(1.-deltax),0.)
      call addpnt(x1,y1,kdata,n,          0.,0.)
      call addpnt(x1,y1,kdata,n,x1(n)*(1.+deltax),0.)
      call addpnt(x1,y1,kdata,n,        1e38,0.)
      call inter2(nw,wl,yg298,   n,x1,     y1,ierr)
      
      do iw = 1,nw-1
        IF ((wc(iw) .GT. 300) .AND. (wc(iw) .LT.398.))  THEN
          yg248(iw) = 1.0
          yg298(iw) = 1.0
        ENDIF
      enddo
      do iw = 1,nw-1
        IF (wc(iw) .GT. 430.) THEN
          yg248(iw) = 0.0
          yg298(iw) = 0.0
        ENDIF
      enddo

!---------------------------------------------------------------
!     ... Check routine 
!      do iw = 64,100
!        print*, iw, wc(iw), yg248(iw), yg298(iw)
!      enddo
!      stop
!---------------------------------------------------------------
      do iw = 1, nw-1
         do iz = 1, nz
           qyno2(iz,iw) = yg248(iw)
           if ((tin(iz) .GE. 248.) .AND. (tin(iz) .le. 298.)) then
             qyno2(iz,iw) = yg248(iw) + 
     $                    (yg298(iw)-yg248(iw))/(298.- 248.) *
     $                    (tin(iz)-248.)
           endif
           if (tin(iz) .GT. 298.) then
             qyno2(iz,iw) = yg298(iw)
           endif
         enddo
      enddo
!-------------------------------------------------------
!     ... Check routine 
!      iz = 1
!      print*, "tin=", tin(iz)
!      do iw = 65,94
!        print*, wc(iw), yg248(iw), yg298(iw), qyno2(iz,iw)
!      enddo
!      stop
!-------------------------------------------------------
!-------------------------------------------------------
!     ... derive the cross section*qy
!-------------------------------------------------------
      do iw = 1, nw - 1
         do iz = 1, nz
            sq(j,iz,iw) = xsno2(iz,iw)*qyno2(iz,iw)
         enddo
      enddo

!-------------------------------------------------------
!     ... Check routine 
!      iz = 1
!      print*, "tin=", tin(iz)
!      do iw = 64, 94
!        print*, wc(iw), xsno2(iz,iw), qyno2(iz,iw), sq(j,iz,iw)
!      enddo
!      stop
!-------------------------------------------------------

!-------------------------------------------------------
!     ... Check routine 
!      do iz = 1, nz
!        print*,iz, tin(iz)
!      enddo
!      stop
!-------------------------------------------------------
      end subroutine XSQY_NO2
