      subroutine XSQY_NO3(nw,wl,wc,nz,tlev,airlev,j,sq,jlabel,pn)
!-----------------------------------------------------------------------------!
!   purpose:                                                                  !
!   provide the product (absorptioon cross section) x (quantum yield) for     !
!   both channels of no3 photolysis:                                          !
!           (a) NO3 + hv -> NO2 + O(3P)                                       !
!           (b) NO3 + hv -> NO + O2                                           !
!   cross section and quantum yield consistent with JPL06                     !
!-----------------------------------------------------------------------------!
!   parameters:                                                               !
!   nw     - integer, number of specified intervals + 1 in working        (i) !
!            wavelength grid                                                  !
!   wl     - real, vector of lower limits of wavelength intervals in      (i) !
!            working wavelength grid                                          !
!   wc     - real, vector of center points of wavelength intervals in     (i) !
!            working wavelength grid                                          !
!   nz     - integer, number of altitude levels in working altitude grid  (i) !
!   tlev   - real, temperature (k) at each specified altitude level       (i) !
!   airlev - real, air density (molec/cc) at each altitude level          (i) !
!   j      - integer, counter for number of weighting functions defined  (io) !
!   sq     - real, cross section x quantum yield (cm^2) for each          (o) !
!            photolysis reaction defined, at each defined wavelength and      !
!            at each defined altitude level                                   !
!   jlabel - character*60, string identifier for each photolysis reaction (o) !
!            defined                                                          !
!-----------------------------------------------------------------------------!
!   edit history:                                                             !
!   02/04/08 Doug Kinnison                                                    !
!-----------------------------------------------------------------------------!

      implicit none
      include 'params'

!-----------------------------------------------------------------------------!
!     ... input                                                               !
!-----------------------------------------------------------------------------!
      real, intent(in) :: wl(kw)
	real, intent(in) :: wc(kw)
      real, intent(in) :: tlev(kz)
      real, intent(in) :: airlev(kz)

      integer, intent(in) :: nz
      integer, intent(in) :: nw
      character*80 pn
      character*60, intent(out) :: jlabel(kj)
      real, intent(out) :: sq(kj,kz,kw)

!-----------------------------------------------------------------------------!
!     ... input/output                                                        !
!-----------------------------------------------------------------------------!
      integer, intent(inout) :: j

!-----------------------------------------------------------------------------!
!     ... local                                                               !
!-----------------------------------------------------------------------------!
      integer kdata
      parameter(kdata=350)
      integer i, iw, iz, n, n1, idum, iskip, ierr
 
      real x1(kdata)
      real y1(kdata), xqy( kdata)
      real qyNO_298 (kdata), qyNO_230 (kdata), qyNO_190 (kdata)
      real qyNO2_298(kdata), qyNO2_230(kdata), qyNO2_190(kdata)
      real ygNO_298 (kw),    ygNO_230 (kw),    ygNO_190 (kw)
      real ygNO2_298(kw),    ygNO2_230(kw),    ygNO2_190(kw)
      real yg(kw), yg1(kw)
      real qyNO2(nz,kw),     qyNO(nz,kz)
      real tin(nz)
      real qy

!----------------------------------------------
!     ... tin set to tlev
!---------------------------------------------
      tin(:) = tlev(:)
 
!----------------------------------------------
!     ... cross section from JPL06:
!---------------------------------------------
      open(unit=kin,
     &     file=TRIM(pn)//'XS_NO3_JPL06.txt',status='old')
      read(kin,*) iskip, n
      do i = 1, iskip
         read(kin,*)
      enddo
      do i = 1, n
        read(kin,*) x1(i), y1(i)
      enddo 
      close (kin)

      x1(:) = x1(:)
      y1(:) = y1(:)
      n     = n
      call addpnt(x1,y1,kdata,n,x1(1)*(1.-deltax),0.)
      call addpnt(x1,y1,kdata,n,          0.,0.)
      call addpnt(x1,y1,kdata,n,x1(n)*(1.+deltax),0.)
      call addpnt(x1,y1,kdata,n,        1e38,0.)
      call inter2(nw,wl,yg,   n,x1,     y1,ierr)

!-------------------------------------------------------
!     ... Check routine 
!      do iw = 88, nw-1
!        print*, iw, wc(iw), yg(iw)
!      enddo
!      stop
!-------------------------------------------------------
!-------------------------------------------------------
!     ... read in and derive qy
!-------------------------------------------------------
      open(unit=kin,
     &     file=TRIM(pn)//'QY_NO3_JPL06.txt',status='old')

      read(kin,*) idum, n1
      do i = 1, idum-2
        read(kin,*)
      enddo

      do iw = 1, n1
        read(kin,*) xqy(iw), qyNO_298(iw),  qyNO_230(iw),  qyNO_190(iw), 
     $                       qyNO2_298(iw), qyNO2_230(iw), qyNO2_190(iw)
        qyNO_298(iw)  = qyNO_298(iw)  / 1000.
        qyNO_230(iw)  = qyNO_230(iw)  / 1000.
        qyNO_190(iw)  = qyNO_190(iw)  / 1000.
        qyNO2_298(iw) = qyNO2_298(iw) / 1000.
        qyNO2_230(iw) = qyNO2_230(iw) / 1000.
        qyNO2_190(iw) = qyNO2_190(iw) / 1000.
      enddo
      close(kin)

!--------------------------------------------------------
!     ... Check routine 
!      do iw = 1, n1
!        print*, iw, xqy(iw), qyNO_298(iw), qyNO2_298(iw)
!      enddo
!      stop
!--------------------------------------------------------    
!     NO2 + O
      x1(:) = xqy(:)
      y1(:) = qyNO2_298(:)
      n     = n1
      call addpnt(x1,y1,kdata,n,x1(1)*(1.-deltax),0.)
      call addpnt(x1,y1,kdata,n,          0.,0.)
      call addpnt(x1,y1,kdata,n,x1(n)*(1.+deltax),0.)
      call addpnt(x1,y1,kdata,n,        1e38,0.)
      call inter2(nw,wl,ygNO2_298,   n,x1,     y1,ierr)
      x1(:) = xqy(:)
      y1(:) = qyNO2_230(:)
      n     = n1
      call addpnt(x1,y1,kdata,n,x1(1)*(1.-deltax),0.)
      call addpnt(x1,y1,kdata,n,          0.,0.)
      call addpnt(x1,y1,kdata,n,x1(n)*(1.+deltax),0.)
      call addpnt(x1,y1,kdata,n,        1e38,0.)
      call inter2(nw,wl,ygNO2_230,   n,x1,     y1,ierr)
      x1(:) = xqy(:)
      y1(:) = qyNO2_190(:)
      n     = n1
      call addpnt(x1,y1,kdata,n,x1(1)*(1.-deltax),0.)
      call addpnt(x1,y1,kdata,n,          0.,0.)
      call addpnt(x1,y1,kdata,n,x1(n)*(1.+deltax),0.)
      call addpnt(x1,y1,kdata,n,        1e38,0.)
      call inter2(nw,wl,ygNO2_190,   n,x1,     y1,ierr)

!.... NO+O2
      x1(:) = xqy(:)
      y1(:) = qyNO_298(:)
      n     = n1
      call addpnt(x1,y1,kdata,n,x1(1)*(1.-deltax),0.)
      call addpnt(x1,y1,kdata,n,          0.,0.)
      call addpnt(x1,y1,kdata,n,x1(n)*(1.+deltax),0.)
      call addpnt(x1,y1,kdata,n,        1e38,0.)
      call inter2(nw,wl,ygNO_298,   n,x1,     y1,ierr)
      x1(:) = xqy(:)
      y1(:) = qyNO_230(:)
      n     = n1
      call addpnt(x1,y1,kdata,n,x1(1)*(1.-deltax),0.)
      call addpnt(x1,y1,kdata,n,          0.,0.)
      call addpnt(x1,y1,kdata,n,x1(n)*(1.+deltax),0.)
      call addpnt(x1,y1,kdata,n,        1e38,0.)
      call inter2(nw,wl,ygNO_230,   n,x1,     y1,ierr)
      x1(:) = xqy(:)
      y1(:) = qyNO_190(:)
      n     = n1
      call addpnt(x1,y1,kdata,n,x1(1)*(1.-deltax),0.)
      call addpnt(x1,y1,kdata,n,          0.,0.)
      call addpnt(x1,y1,kdata,n,x1(n)*(1.+deltax),0.)
      call addpnt(x1,y1,kdata,n,        1e38,0.)
      call inter2(nw,wl,ygNO_190,   n,x1,     y1,ierr)

!---------------------------------------------------------------
!     ... Check routine 
!      do iw = 95,101
!        print*, iw, wc(iw), ygNO_298(iw), ygNO2_298(iw)
!      enddo
!      stop
!---------------------------------------------------------------  
!... NO2 + O 
      do iw = 1, nw-1

         do iz = 1, nz

           IF (wc(iw) .GE. 585.) THEN
           qyNO2(iz,iw) = ygNO2_190(iw)
           if ((tin(iz) .GE. 190.) .AND. (tin(iz) .le. 230.)) then
             qyNO2(iz,iw) = ygNO2_190(iw) + 
     $                    (ygNO2_230(iw)-ygNO2_190(iw))/(230.- 190.) *
     $                    (tin(iz)-190.)
           endif
           if ((tin(iz) .GT. 230.) .AND. (tin(iz) .le. 298.)) then
             qyNO2(iz,iw) = ygNO2_230(iw) + 
     $                    (ygNO2_298(iw)-ygNO2_230(iw))/(298.- 230.) *
     $                    (tin(iz)-230.)
           endif
           if (tin(iz) .GT. 298.) then
             qyNO2(iz,iw) = ygNO2_298(iw)
           endif
!... NO + O2
           qyNO(iz,iw) = ygNO_190(iw)
           if ((tin(iz) .GE. 190.) .AND. (tin(iz) .le. 230.)) then
             qyNO(iz,iw) = ygNO_190(iw) + 
     $                    (ygNO_230(iw)-ygNO_190(iw))/(230.- 190.) *
     $                    (tin(iz)-190.)
           endif
           if ((tin(iz) .GT. 230.) .AND. (tin(iz) .le. 298.)) then
             qyNO(iz,iw) = ygNO_230(iw) + 
     $                    (ygNO_298(iw)-ygNO_230(iw))/(298.- 230.) *
     $                    (tin(iz)-230.)
           endif
           if (tin(iz) .GT. 298.) then
             qyNO(iz,iw) = ygNO_298(iw)
           endif

           ELSE
             qyNO(iz,iw) = 0.
             qyNO2(iz,iw)= 1.
           ENDIF
         enddo
      enddo
!---------------------------------------------------------------
!     ... Check routine 
!      print*, " NO+O2     NO2+O"
!     iz =1
!      print*, "tin=", tin(iz)
!      do iw = 88,nw-1
!        print*, iw, wc(iw), yg(iw), qyNO(iz,iw), qyNO2(iz,iw)
!      enddo
!      stop
!---------------------------------------------------------------  
      j = j + 1
      jlabel(j) = 'NO3 + hv -> NO2 + O(3P)'

      do iw = 1, nw-1
        do iz = 1, nz
          sq(j,iz,iw) = qyNO2(iz,iw) * yg(iw)
 
        enddo
      enddo 
!----------------------------------------------------------------
!         for   no3 ->no+o2
!----------------------------------------------------------------
      j = j + 1
      jlabel(j) = 'NO3 + hv  -> NO + O2'

      do iw = 1, nw-1
        do iz = 1, nz
          sq(j,iz,iw) = qyNO(iz,iw) * yg(iw)
 
        enddo
      enddo 
!---------------------------------------------------------------
!     ... Check routine 
!      iz = 1
!      print*, "tin=", tin(iz)
!      print*, " NO+O2     NO2+O"
!      do iw = 88,nw-1
!        print*, iw, wc(iw), sq(j,iz,iw), sq(j-1,iz,iw)
!      enddo
!      stop
!---------------------------------------------------------------  
      end subroutine XSQY_NO3
