      subroutine XSQY_NO3(nw,wl,wc,nz,tlev,airlev,j,sq,jlabel,pn)
!-----------------------------------------------------------------------------!
!   purpose:                                                                  !
!   provide the product (absorptioon cross section) x (quantum yield) for     !
!   both channels of no3 photolysis:                                          !
!           (a) no3 + hv -> no2 + o(3p)                                       !
!           (b) no3 + hv -> no + o2                                           !
!   cross section combined from graham and johnston (<600 nm) and jpl 94      !
!   quantum yield from madronich (1988)                                       !
!-----------------------------------------------------------------------------!
!   parameters:                                                               !
!   nw     - integer, number of specified intervals + 1 in working        (i) !
!            wavelength grid                                                  !
!   wl     - real, vector of lower limits of wavelength intervals in      (i) !
!            working wavelength grid                                          !
!   wc     - real, vector of center points of wavelength intervals in     (i) !
!            working wavelength grid                                          !
!   nz     - integer, number of altitude levels in working altitude grid  (i) !
!   tlev   - real, temperature (k) at each specified altitude level       (i) !
!   airlev - real, air density (molec/cc) at each altitude level          (i) !
!   j      - integer, counter for number of weighting functions defined  (io) !
!   sq     - real, cross section x quantum yield (cm^2) for each          (o) !
!            photolysis reaction defined, at each defined wavelength and      !
!            at each defined altitude level                                   !
!   jlabel - character*60, string identifier for each photolysis reaction (o) !
!            defined                                                          !
!-----------------------------------------------------------------------------!
!   edit history:                                                             !
!   05/98  original, adapted from former jspec1 subroutine                    !
!-----------------------------------------------------------------------------!
!  this program is free software;  you can redistribute it and/or modify      !
!  it under the terms of the gnu general public license as published by the   !
!  free software foundation;  either version 2 of the license, or (at your    !
!  option) any later version.                                                 !
!  the tuv package is distributed in the hope that it will be useful, but     !
!  without any warranty;  without even the implied warranty of merchantibi-   !
!  lity or fitness for a particular purpose.  see the gnu general public      !
!  license for more details.                                                  !
!  to obtain a copy of the gnu general public license, write to:              !
!  free software foundation, inc., 675 mass ave, cambridge, ma 02139, usa.    !
!-----------------------------------------------------------------------------!
      implicit none
      include 'params'

!-----------------------------------------------------------------------------!
!     ... input                                                               !
!-----------------------------------------------------------------------------!
      real, intent(in) :: wl(kw)
	real, intent(in) :: wc(kw)
      real, intent(in) :: tlev(kz)
      real, intent(in) :: airlev(kz)

      integer, intent(in) :: nz
      integer, intent(in) :: nw
      character*80 pn
      character*60, intent(out) :: jlabel(kj)
      real, intent(out) :: sq(kj,kz,kw)

!-----------------------------------------------------------------------------!
!     ... input/output                                                        !
!-----------------------------------------------------------------------------!
      integer, intent(inout) :: j

!-----------------------------------------------------------------------------!
!     ... local                                                               !
!-----------------------------------------------------------------------------!
      integer kdata
      parameter(kdata=350)
      real x1(kdata)
      real y1(kdata)
      real yg(kw), yg1(kw)
      real qyNO(kw), qyNO2(kw)
      integer irow, icol
      integer i, iw, n, idum, iskip
      integer ierr

!----------------------------------------------
!     ... jlabel(j) = 'NO3 -> NO2 + O (3P)
!     ... jlabel(j) = 'NO3 -> NO + O2'
!----------------------------------------------

!----------------------------------------------------------------
!     ... cross section measurements of graham and johnston 1978
!----------------------------------------------------------------
      open(unit=kin,
     &     file=TRIM(pn)//'NO3_gj78.abs',status='old')
	read(kin,*) iskip, n
      do i = 1, iskip
        read(kin,*) 
      end do
     
      do irow = 1, 30
         read(kin,*) ( y1(10*(irow-1) + icol), icol =  1, 10 )
      enddo
      read(kin,*) ( y1(300 + icol), icol = 1, 5 )
      close (kin)
      
	n=305
      do i = 1, n
         y1(i) =  y1(i) * 1.e-19
         x1(i) = 400. + 1.*float(i-1)
      enddo

      call addpnt(x1,y1,kdata,n,x1(1)*(1.-deltax),0.)
      call addpnt(x1,y1,kdata,n,               0.,0.)
      call addpnt(x1,y1,kdata,n,x1(n)*(1.+deltax),0.)
      call addpnt(x1,y1,kdata,n,           1.e+38,0.)
      call inter2(nw,wl,yg,n,x1,y1,ierr)
      if (ierr .ne. 0) then
         write(*,*) ierr, jlabel(j)
         stop
      endif

!-------------------------------------
!     ... cross section from jpl94:
!-------------------------------------
      open(unit=kin,
     &     file=TRIM(pn)//'NO3_jpl94.abs',status='old')
      read(kin,*) iskip, n
      do i = 1, iskip
         read(kin,*)
      enddo
      do i = 1, n
        read(kin,*) x1(i), y1(i)
        y1(i) = y1(i)*1e-20
      enddo 
      close (kin)

      call addpnt(x1,y1,kdata,n,x1(1)*(1.-deltax),0.)
      call addpnt(x1,y1,kdata,n,               0.,0.)
      call addpnt(x1,y1,kdata,n,x1(n)*(1.+deltax),0.)
      call addpnt(x1,y1,kdata,n,           1.e+38,0.)
      call inter2(nw,wl,yg1,n,x1,y1,ierr)
      if (ierr .ne. 0) then
         write(*,*) ierr, jlabel(j)
         stop
      endif
!----------------------------------------------------------------
!     ... use jpl94 for wavelengths longer than 600 nm
!----------------------------------------------------------------
      do iw = 1, nw-1
         if(wl(iw) .gt. 600.) yg(iw) = yg1(iw)
      enddo

!----------------------------------------------------------------
!     ... for  no3 ->no2+o
!----------------------------------------------------------------

      j = j + 1
      jlabel(j) = 'NO3 + hv -> NO2 + O(3P)'
      do iw = 1, nw - 1
         if (wc(iw).lt.584.) then
            qyNO2(iw) = 1.
         elseif (wc(iw).gt.640.) then
            qyNO2(iw)  = 0.
         elseif (wc(iw).gt.595.) then
            qyNO2(iw) = 0.65*(1-(wc(iw)-595.)/45.)
         else
            qyNO2(iw) = 1.-0.35*(wc(iw)-584.)/11.
         endif
         do i = 1, nz
            sq(j,i,iw) = yg(iw)*qyNO2(iw)
         enddo
      enddo
!----------------------------------------------------------------
!     ... quantum yield: from madronich (1988) see cec no3 book.
!         for   no3 ->no+o2
!----------------------------------------------------------------
      j = j + 1
      jlabel(j) = 'NO3 + hv -> NO + O2'
      do iw = 1, nw - 1
         if (wc(iw).lt.584.) then 
            qyNO(iw) = 0.
         elseif (wc(iw).ge.640.) then
            qyNO(iw) = 0.
         elseif (wc(iw).ge.595.) then 
            qyNO(iw) = 0.35*(1.-(wc(iw)-595.)/45.)
         else
            qyNO(iw) = 0.35*(wc(iw)-584.)/11.
         endif
         do i = 1, nz
            sq(j,i,iw) = yg(iw)*qyNO(iw)
         enddo
      enddo
!-------------------------------------------------------
!     ... Check routine 
!      do iw = 88, nw-1
!  v   print*, iw, wc(iw), yg(iw), qyNO(iw), qyNO2(iw)
!      enddo
!      stop
!-------------------------------------------------------
      end subroutine XSQY_NO3
