      subroutine XSQY_O3(nw,wl,wc,nz,tlev,airlev,j,sq,jlabel,pn)
!-----------------------------------------------------------------------------!
!   purpose:                                                                  !
!   provide the product of (cross section) x (quantum yield) for the two      !
!   o3 photolysis reactions:                                                  !
!              (a) O3 + hv -> O2 + O(1D)                                      !
!              (b) O3 + hv -> O2 + O(3P)                                      !
!   cross sections:                                                           !
!               120nm - 185 nm = Ackerman, 1971                               !
!               185nm - 827 nm = JPL06 (293-298K)                             !
!               196nm - 342 nm = JPL06 (218 K)                                !
!   quantum yield:  JPL 06 recommendation                                     !
!-----------------------------------------------------------------------------!
!   parameters:                                                               !
!   nw     - integer, number of specified intervals + 1 in working        (i) !
!            wavelength grid                                                  !
!   wl     - real, vector of lower limits of wavelength intervals in      (i) !
!            working wavelength grid                                          !
!   wc     - real, vector of center points of wavelength intervals in     (i) !
!            working wavelength grid                                          !
!   nz     - integer, number of altitude levels in working altitude grid  (i) !
!   tlev   - real, temperature (k) at each specified altitude level       (i) !
!   airlev - real, air density (molec/cc) at each altitude level          (i) !
!   j      - integer, counter for number of weighting functions defined  (io) !
!   sq     - real, cross section x quantum yield (cm^2) for each          (o) !
!            photolysis reaction defined, at each defined wavelength and      !
!            at each defined altitude level                                   !
!   jlabel - character*60, string identifier for each photolysis reaction (o) !
!            defined                                                          !
!-----------------------------------------------------------------------------!
!   edit history:                                                             !
!   02/06/08  JPL-06 Doug Kinnison                                            !
!   01/02  Atkinson, 1971, 120-175nm, Doug Kinnison                           !
!-----------------------------------------------------------------------------!
      implicit none

      include 'params'
!-----------------------------------------------------------------------------!
!     ... input                                                               !
!-----------------------------------------------------------------------------!
      real, intent(in) :: wl(kw)
      real, intent(in) :: wc(kw)
      real, intent(in) :: tlev(kz)
      real, intent(in) :: airlev(kz)

      integer, intent(in) :: nz
      integer, intent(in) :: nw
      
      character*80 pn
      character*60, intent(out) :: jlabel(kj)
      real, intent(out) :: sq(kj,kz,kw)

!     ... input/output:
      integer, j

!-----------------------------------------------------------------------------!
!     ... Local arrays                                                        !
!-----------------------------------------------------------------------------!

      integer, parameter :: kdata = 250
      integer n1, n2, n3, iskip, ierr
      integer i, iw, iz, n, idum, kk
      real x1    (kdata), x2   (kdata), x3(kdata), x5(13)
      real y1    (kdata), y2   (kdata), y3(kdata), y5(13)
      real qy3p  (kz,kw), so3  (kz,kw)
      real QY_O1D(nz,kw), QY_marsh(kw)
      real yg298(kw), yg218(kw), xso3(kw)
      real tin(kz), yg(kw)
      real A(3), X(3), om(3)
      real a1, a2, a3, w, t, kt, dum, q1, q2

      DATA A/ 0.8036, 8.9061, 0.1192/
      DATA X/ 304.225, 314.957, 310.737/
      DATA om/ 5.576, 6.601, 2.187/

!-----------------------------------------------------------
!     ... tin set to tlev
!-----------------------------------------------------------
      tin(:) = tlev(:)

!-----------------------------------------------------------
!     ... jlabel(j) = 'O3 -> O2 + O(1D)'
!     ... jlabel(j) = 'O3 -> O2 + O(3P)'
!-----------------------------------------------------------
      j = j + 1
      jlabel(j) = 'O3 + hv -> O2 + O(1D)'
      
      j = j + 1
      jlabel(j) = 'O3 + hv -> O2 + O(3P)'

!-----------------------------------------------------------
!     Ref: Atkinson, ultraviolet solar radiation related to 
!          mesopheric procesess, 149-159, in fiocco, g. (ed.), 
!          mesospheric models and related exp., d. reidel, 
!          dordrecht, 1971. 
!
!          120 nm through 200 nm
!-----------------------------------------------------------
      open(unit=kin,file=TRIM(pn)//'XS_O3_Ackerman_1971.txt',
     $     status='old')
      read(kin,*) iskip, n
      do i = 1, iskip
        read(kin,*) 
      end do
      do i = 1, n
        read(kin,*) x1(i), y1(i)
      enddo
      close(kin)

      call addpnt(x1,y1,kdata,n,x1(1)*(1.-deltax),0.)
      call addpnt(x1,y1,kdata,n,               0.,0.)
      call addpnt(x1,y1,kdata,n,x1(n)*(1.+deltax),0.)
      call addpnt(x1,y1,kdata,n,           1.e+38,0.)
      call inter2(nw,wl,yg,n,x1,y1,ierr)
      if (ierr .ne. 0) then
         write(*,*) ierr, jlabel(j)
         stop
      endif

      do iw = 1, nw-1
         xso3(iw) = yg(iw)
      enddo
!-------------------------------------------------------
!     ... Check routine 
!      do iw = 1,36
!        print*, iw, wc(iw), yg(iw)
!      enddo
!      stop
!-------------------------------------------------------
!-------------------------------------------------------
!     ... REF: JPL06 218K
!         from 196.078 to 342.5 nm
!-------------------------------------------------------
      open(unit=kin,file=TRIM(pn)//'XS_O3_218_JPL06.txt',
     $     status='old')
      read(kin,*) iskip, n
      do i = 1, iskip
        read(kin,*) 
      end do
      do i = 1, n
        read(kin,*) a1, a2, y2(i)
        x2(i) = (a1+a2)/2.
!        print*, x2(i), y2(i)
      enddo
      close(kin)

      call addpnt(x2,y2,kdata,n,x2(1)*(1.-deltax),0.)
      call addpnt(x2,y2,kdata,n,               0.,0.)
      call addpnt(x2,y2,kdata,n,x2(n)*(1.+deltax),0.)
      call addpnt(x2,y2,kdata,n,           1.e+38,0.)
      call inter2(nw,wl,yg218,n,x2,y2,ierr)
      if (ierr .ne. 0) then
         write(*,*) ierr, jlabel(j)
         stop
      endif
!-------------------------------------------------------
!     ... Check routine 
!      do iw = 1,nw-1
!        print*, iw, wc(iw), yg218(iw)
!      enddo
!      stop
!-------------------------------------------------------
!-------------------------------------------------------
!     ... REF: JPL06 293-298K
!         from 185.185 to 827.500 nm
!-------------------------------------------------------
      open(unit=kin,file=TRIM(pn)//'XS_O3_298_JPL06.txt',
     $     status='old')
      read(kin,*) iskip, n
      do i = 1, iskip
        read(kin,*) 
      end do
      do i = 1, n
        read(kin,*) a1, a2, y3(i)
        x3(i) = (a1+a2)/2.
      enddo
      close(kin)

      call addpnt(x3,y3,kdata,n,x3(1)*(1.-deltax),0.)
      call addpnt(x3,y3,kdata,n,               0.,0.)
      call addpnt(x3,y3,kdata,n,x3(n)*(1.+deltax),0.)
      call addpnt(x3,y3,kdata,n,           1.e+38,0.)
      call inter2(nw,wl,yg298,n,x3,y3,ierr)
      if (ierr .ne. 0) then
         write(*,*) ierr, jlabel(j)
         stop
      endif
!-------------------------------------------------------
!     ... Check routine 
!      do iw = 1,nw-1
!      print*, iw, wc(iw), yg298(iw)
!      enddo
!      stop
!-------------------------------------------------------
      do iw = 1, nw-1
	if (wc(iw) .ge. 184.0) then
           xso3(iw) = yg298(iw)
	endif
      enddo
!-------------------------------------------------------
!     ... Check routine 
!      do iw = 1,nw-1
!        print*, iw, wc(iw), xso3(iw)
!      enddo
!      stop
!-------------------------------------------------------
!-------------------------------------------------------
!     ... for hartley and huggins bands, use 
!         temperature-dependent values from
!         JPL06
!-------------------------------------------------------
!-------------------------------------------------------
!     ... Cross Sections and Quantum Yields
!-------------------------------------------------------
      do iw = 1, nw-1
         do iz = 1, nz

         so3(iz,iw) = xso3(iw)

           if ((wc(iw) .ge. 196.078) .and. (wc(iw) .le. 342.5)) then

             if (tin(iz) .lt. 218.) then
               so3(iz,iw) = yg218(iw)
             endif
             if ((tin(iz) .ge. 218.) .and. (tin(iz) .le. 298.)) then
               so3(iz,iw) = yg218(iw)+(yg298(iw)-yg218(iw))/(298.-218.)*
     $                 (tin(iz)-218.)
             endif
             if (tin(iz) .gt. 298.) then
               so3(iz,iw) = yg298(iw)
             endif
           endif

          enddo
       enddo
!-----------------------------------------------------------
!     ... Check routine 
!      iz = 1
!      print*, "tin=", tin(iz)
!      do iw = 26,78
!        print*, iw, wc(iw), so3(iz,iw)
!      enddo
!      stop
!-----------------------------------------------------------
!     ... Impose qy from marsh (thesis 1999) - for 
!         mesospheric production
!-----------------------------------------------------------
 
!     ... wavelengths (nm) consistent with qy
           data x5 /157.6, 193.0, 221.5, 222.0, 228.5, 
     $              231.0, 235.0, 243.5, 248.0, 253.7,
     $              266.0, 274.0, 280.0/

!     ... qy taken from several sources (see marsh)
           data y5 /0.29, 0.46, 0.87, 0.87, 0.83, 
     $              0.83, 0.88, 0.88, 0.91, 0.92,
     $              0.88, 0.90, 0.90/
	do kk = 1, 13
	  x1(kk) = x5(kk)
	  y1(kk) = y5(kk)
      enddo
      n = 13 
      call addpnt(x1,y1,kdata,n,120.0,0.3)
      call addpnt(x1,y1,kdata,n,          0.,0.)
      call addpnt(x1,y1,kdata,n,x1(n)*(1.+deltax),0.90)
      call addpnt(x1,y1,kdata,n,        1e38,0.)

      call inter2(nw,wl,qy_marsh,n,x1,y1,ierr)

!------------------------------------------------------
!     ... Check routine 
!      do iw = 1,78
!        print*, iw, wc(iw), qy_marsh(iw)
!      enddo
!      stop
!------------------------------------------------------ 
!     ... QY JPL06
!         Valid from 306-328 nm
!                    200-320 K
!------------------------------------------------------ 
      do iz = 1, nz
        T = max(min(320.0, tin(iz)),200)

        do iw = 1, nw-1 
          
          kt = 0.695 * T
          q1 = 1.
          q2 = exp(-825.518/kT)
      
          IF(wc(iw) .LE. 280.) THEN
             QY_O1D (iz,iw) = qy_marsh(iw)
          ELSEIF (wc(iw) .LE. 305.) THEN
             QY_O1D (iz,iw) = 0.9
          ELSEIF((wc(iw) .GT. 305) .AND. (wc(iw) .LE. 328.)) THEN

          QY_O1D(iz,iw)  = 0.0765 + 
     $    a(1)*             (q1/(q1+q2))*EXP(-((x(1)-wc(iw))/om(1))**4)+ 
     $    a(2)*(T/300.)**2 *(q2/(q1+q2))*EXP(-((x(2)-wc(iw))/om(2))**2)+
     $    a(3)*(T/300.)**1.5            *EXP(-((x(3)-wc(iw))/om(3))**2)

          ELSEIF(wc(iw) .GT. 328. .AND. wc(iw) .LE. 345.) THEN
             QY_O1D(iz,iw) = 0.08
          ELSEIF(wc(iw) .GT. 340.) THEN
             QY_O1D(iz,iw) = 0.
          ENDIF
           
          QY_O1D(iz,iw) = min(qy_O1D(iz,iw),1.0)
        enddo

      enddo
!------------------------------------------------------ 
!     ... Check routine 
!      iz = 100
!      print*,"tin=", tin(iz)
!      do iw = 1,78
!        print*, iw, wc(iw), qy_o1d(iz,iw), 1-qy_o1d(iz,iw), so3(iz,iw)
!      enddo
!      stop
!------------------------------------------------------ 
!------------------------------------------------------
!     ... derive the cross section*qy
!------------------------------------------------------
      do iz = 1, nz
         do iw = 1, nw-1
           sq(j-1,iz,iw) = qy_O1D(iz,iw)*so3(iz,iw)
           qy3p(iz,iw)   = 1.0      - qy_O1D(iz,iw)
           sq(j,iz,iw)   = qy3p(iz,iw)  *so3(iz,iw)
         enddo
      enddo
!------------------------------------------------------
!     ... Check routine 
!      iz = 125
!      print*,"tin=", tin(iz)
!      do iw = 1,nw-1
!        print*, wc(iw),sq(j,iz,iw), qy_o1d(iz,iw)
!      enddo
!     
!      iw = 68
!      print*,"wc=",  wc(iw)
!      do iz = 115, 135
!         print*, iz, sq(j,iz,iw), qy3p(iz,iw),qy_O1D(iz,iw), so3(iz,iw) 
!      enddo      
!      stop    
!------------------------------------------------------ 
      end subroutine XSQY_O3
