      SUBROUTINE XSQY_PAN(nw,wl,wc,nz,tlev,airden,j,sq,jlabel,pn)
!---------------------------------------------------------------------------!
!  PURPOSE:                                                                 !
!  Provide product (cross section) x (quantum yield) for PAN photolysis:    !
!       PAN + hv -> Products                                                !
!                                                                           !
!  Cross section: from Talukdar et al., 1995                                !
!  Quantum yield: Assumed to be unity                                       !
!---------------------------------------------------------------------------!
!  PARAMETERS:                                                              !
!  NW     - INTEGER, number of specified intervals + 1 in working        (I)!
!           wavelength grid                                                 !
!  WL     - REAL, vector of lower limits of wavelength intervals in      (I)!
!           working wavelength grid                                         !
!  WC     - REAL, vector of center points of wavelength intervals in     (I)!
!           working wavelength grid                                         !
!  NZ     - INTEGER, number of altitude levels in working altitude grid  (I)!
!  TLEV   - REAL, temperature (K) at each specified altitude level       (I)!
!  AIRDEN - REAL, air density (molec/cc) at each altitude level          (I)!
!  J      - INTEGER, counter for number of weighting functions defined  (IO)!
!  SQ     - REAL, cross section x quantum yield (cm^2) for each          (O)!
!           photolysis reaction defined, at each defined wavelength and     !
!           at each defined altitude level                                  !
!  JLABEL - CHARACTER*50, string identifier for each photolysis reaction (O)!
!           defined                                                         !
!---------------------------------------------------------------------------!
      IMPLICIT NONE
      INCLUDE 'params'

!---------------------------------------------------------------------------!
!     ... input                                                             !
!---------------------------------------------------------------------------!
      real, intent(in) :: wl(kw)
      real, intent(in) :: wc(kw)
      real, intent(in) :: tlev(kz)
      real, intent(in) :: airden(kz)

      integer, intent(in) :: nz
      integer, intent(in) :: nw

      character*80, intent(in) ::  pn
      character*60, intent(out) :: jlabel(kj)
      real, intent(out) :: sq(kj,kz,kw)

!---------------------------------------------------------------------------!
!     ... input/output                                                      !
!---------------------------------------------------------------------------!
      integer, intent(inout) :: j

!---------------------------------------------------------------------------!
!     ... local                                                             !
!---------------------------------------------------------------------------!
      integer   kdata
      parameter (kdata=100)
      integer i, iw, n, n2, ierr, iz, idum
      real  x1(kdata), x2(kdata)
      real  y1(kdata), y2(kdata)
      real  yg(kw), yg2(kw)
      real  tin(nz)
      real  qy, sig

!----------------------------------------------
!     ... tin set to tlev
!----------------------------------------------
      tin(:) = tlev(:)
    
!----------------------------------------------
!     ... PAN photodissociation
!----------------------------------------------
      j = j+1
      jlabel(j) = 'PAN + hv -> Products'

!----------------------------------------------
!      JPL06 based on:
!      Talukdar et al., 1995, J.Geophys.Res. 
!----------------------------------------------
      open(kin,file=TRIM(pn)//'XS_PAN_JPL06.txt',status='old')

      read(kin,*) idum, n
      do i = 1, idum-2
        read(kin,*)
      enddo

      do i = 1, n
         read(kin,*) x1(i), y1(i), y2(i)
         y1(i) = y1(i) * 1.E-20
         y2(i) = y2(i) * 1E-3
         x2(i) = x1(i)
      enddo
      close(kin)
      n2 = n
 
      CALL addpnt(x1,y1,kdata,n,x1(1)*(1.-deltax),0.)
      CALL addpnt(x1,y1,kdata,n,               0.,0.)
      CALL addpnt(x1,y1,kdata,n,x1(n)*(1.+deltax),0.)
      CALL addpnt(x1,y1,kdata,n,           1.e+38,0.)
      CALL inter2(nw,wl,yg,n,x1,y1,ierr)
      IF (ierr .NE. 0) THEN
         WRITE(*,*) ierr, jlabel(j)
         STOP
      ENDIF

      CALL addpnt(x2,y2,kdata,n2,x2(1)*(1.-deltax),0.)
      CALL addpnt(x2,y2,kdata,n2,          0.,0.)
      CALL addpnt(x2,y2,kdata,n2,x2(n2)*(1.+deltax),0.)
      CALL addpnt(x2,y2,kdata,n2,      1.e+38,0.)
      CALL inter2(nw,wl,yg2,n2,x2,y2,ierr)
      IF (ierr .NE. 0) THEN
         WRITE(*,*) ierr, jlabel(j)
         STOP
      ENDIF

!----------------------------------------------
!    ... Quantum yield
!----------------------------------------------
      qy = 1.0

      DO iw = 1, nw-1
        DO iz = 1, nz

          sig = yg(iw) * EXP(yg2(iw)*(tin(iz)-298.))

          sq(j,iz,iw) = qy * sig

        ENDDO
      ENDDO 
!-------------------------------------------------------
!     ... Check routine
!      iz = 1
!      print*, 'tin=', tin(iz) 
!      do iw =30,80
!        print*, iw, wc(iw), sq(j,iz,iw)
!      enddo
!      stop
!-------------------------------------------------------
      end subroutine XSQY_PAN
