	subroutine CALCJNO(nz, nw, wl, wc,
     $                 xso3,etfphot, n2cc, o2scol,o3scol,noscol,jno)
!-----------------------------------------------------------------------------!
!   PURPOSE:                                                                  !
!   Compute the total photolytic rate constant for NO in the SR bands         !
!     - following the approach of Minshwanner and Siskind, JGR,               !
!       98, D11, 20401-20412, 1993.                                           !
!                                                                             !
!-----------------------------------------------------------------------------!
!   NPUT VARIABLES:                                                           !
!   nz           - INTEGER, number of specified altitude levels               !
!   nw           - INTEGER, number of specified intervals + 1                 !
!   wl           - REAL, vector of lxower limits of wavelength intervals in   !
!                  working wavelength grid                                    !
!                  vertical layer at each specified wavelength                !                                                                !
!   wc           - center of grid (nm)                                        !                                                         !
!   etfphot      - Extraterrestrial Flux                                      !
!                  multilply by (etf(iw)*5.039e11 * wc(iw)) to get            !
!                  units of photons cm-2 sec-1 nm-1                           !
!   n2cc         - N2 conc (molecules cm-3)                                   !
!   o3scol       - Ozone Slant Column (molecules cm-2)                        !
!   o2scol       - O2 Slant Column (molecules cm-2)                           !
!   noscol       - Nitric Oxide Slant Column(molecules cm-2)                  !
!   xso3         - Ozone absorption cross section (cm2 molecule-1)            !
!                                                                             !
!   LOCAL VARIABLES:                                                          !
!   TAUO3        - Transmission factor in the Hartley Band of O3              !
!   etfphot_ms93 - Solar Irr. on Minschwaner and Siskind 1993 (MS93) Grid     ! 
!   XS_O3ms93    - O3 cross section on the MS93 Grid                          !
!                                                                             !
!   OUTPUT VARIABLES:                                                         !
!   JNO          - photolytic rate constant                                   !
!                  each specified altitude                                    !
!                                                                             !
!-----------------------------------------------------------------------------!
!   EDIT HISTORY:                                                             !
!   08/01  Modified by, Doug Kinnison, NCAR, ACD                              !
!   08/01  Taken from Socrates Radiative Transfer Model - author unknown      !
!-----------------------------------------------------------------------------!
      implicit none
      include 'params'

!----------------------------------------------------------------
!	... args
!----------------------------------------------------------------
	integer, intent(in)  :: nw
	integer, intent(in)  :: nz
	real,    intent(in)  :: etfphot(kw)
	real,    intent(in)  :: n2cc(kz)
	real,    intent(in)  :: o2scol(kz)
        real,    intent(in)  :: o3scol(kz)
	real,    intent(in)  :: noscol(nz)
	real,    intent(in)  :: xso3(kw)
        real,    intent(in)  :: wl(kw)
	real,    intent(in)  :: wc(kw)

	real,    intent(out) :: jno(kz)

!----------------------------------------------------------------
!	... local variables
!----------------------------------------------------------------

	integer  i, iw, n

	real tauo3(nz,4)
	real etfphot_ms93(5)
	real xso3_ms93(5)
	real wc_ms93(4)
	real delta_wc_ms93(4)

        real jno50
	real jno90
	real jno100

      real, save, dimension(6,2)  ::  wtno50, csno50, wtno90, csno90,
     $                                wtno100, csno100

!----------------------------------------------------------------
!	... Minschwaner and Siskind SRB Grid (nm)
!----------------------------------------------------------------
      real, save :: wl_ms93(5) = (/ 181.6, 183.1, 184.6, 190.2,
     $                              192.5 /)

!----------------------------------------------------------------
!   	... O2 SRB Cross Sections for the six ODF regions, MS, 1993
!----------------------------------------------------------------
      real, save :: cs250(6)  = (/ 1.117e-23, 2.447e-23, 7.188e-23,
     $                             3.042e-22, 1.748e-21, 1.112e-20 /)
      real, save :: cs290(6)  = (/ 1.350e-22, 2.991e-22, 7.334e-22,
     $                             3.074e-21, 1.689e-20, 1.658e-19 /)
      real, save :: cs2100(6) = (/ 2.968e-22, 5.831e-22, 2.053e-21,
     $                             8.192e-21, 4.802e-20, 2.655e-19 /)
	integer lev

!----------------------------------------------------------------
!   	... 6 sub-intervals for o2 5-0 at 265k,
!	    2 sub-sub-intervals for no 0-0 at 250k
!----------------------------------------------------------------
      real, save :: a(24) = (/ 0., 0., 0., 0.0,
     $             5.12e-02, 5.68e-03, 1.32e-18, 4.41e-17,
     $             1.36e-01, 1.52e-02, 6.35e-19, 4.45e-17,
     $             1.65e-01, 1.83e-02, 7.09e-19, 4.50e-17,
     $             1.41e-01, 1.57e-02, 2.18e-19, 2.94e-17,
     $             4.50e-02, 5.00e-03, 4.67e-19, 4.35e-17 /)

!----------------------------------------------------------------
!   	... sub-intervals for o2 9-0 band,calcjno.f
!	    2 sub-sub-intervals for no 1-0 at 250 k
!----------------------------------------------------------------
      real, save :: b(24) = (/ 0., 0., 0., 0.,
     $           0.00e+00, 0.00e+00, 0.00e+00, 0.00e+00,
     $           1.93e-03, 2.14e-04, 3.05e-21, 3.20e-21,
     $           9.73e-02, 1.08e-02, 5.76e-19, 5.71e-17,
     $           9.75e-02, 1.08e-02, 2.29e-18, 9.09e-17,
     $           3.48e-02, 3.86e-03, 2.21e-18, 6.00e-17 /)

!----------------------------------------------------------------
! 	... sub-intervals for o2 10-0 band,
!	    2 sub-sub-intervals for no 1-0 at 250 k
!----------------------------------------------------------------
      real, save :: c(24) = (/
     $           4.50e-02, 5.00e-03, 1.80e-18, 1.40e-16,
     $           1.80e-01, 2.00e-02, 1.50e-18, 1.52e-16,
     $           2.25e-01, 2.50e-02, 5.01e-19, 7.00e-17,
     $           2.25e-01, 2.50e-02, 7.20e-20, 2.83e-17,
     $           1.80e-01, 2.00e-02, 6.72e-20, 2.73e-17,
     $           4.50e-02, 5.00e-03, 1.49e-21, 6.57e-18 /)

!----------------------------------------------------------------
!    	... note: first 2 sub-intervals in 10-0 band
!           slightly modified for accuracy
!----------------------------------------------------------------
      logical, save :: entered  = .false.

      if ( .not. entered ) then
         wtno50 (1:6,1) = a(1:24:4)
         wtno50 (1:6,2) = a(2:24:4)
         csno50 (1:6,1) = a(3:24:4)
         csno50 (1:6,2) = a(4:24:4)
         wtno90 (1:6,1) = b(1:24:4)
         wtno90 (1:6,2) = b(2:24:4)
         csno90 (1:6,1) = b(3:24:4)
         csno90 (1:6,2) = b(4:24:4)
         wtno100(1:6,1) = c(1:24:4)
         wtno100(1:6,2) = c(2:24:4)
         csno100(1:6,1) = c(3:24:4)
         csno100(1:6,2) = c(4:24:4)
         entered = .true.
      end if

!----------------------------------------------------------------
!   	...interpolate the mean value for the solar irradiance
!        from the kockarts srb grid to the minsch. and siskind
!        grid. 
!----------------------------------------------------------------
!     ...spherical irradiance (actinic flux) as a function of altitude

	n = 5
	call inter4(n,wl_ms93,etfphot_ms93,nw,wl,etfphot,0)

	do i = 1, 4
	  wc_ms93(i) = wl_ms93(i) + (wl_ms93(i+1)-wl_ms93(i)) / 2.0
	  delta_wc_ms93(i) = (wl_ms93(i+1)-wl_ms93(i)) 
	enddo 
 
!----------------------------------------------------------------
!   	...determine the absorption of ozone in the hartley band
!        using a transmission factor and interpolate 
!        from the kockarts srb grid to the minsch. and siskind
!        grid. 
!
!     ...cross sections:
!     ...  from wmo 1985 ozone assessment
!     ...  from 175.439 to 847.500 nm
!     ...  use value at 273 k
!----------------------------------------------------------------
        n=5
	  call inter4(n,wl_ms93,xso3_ms93,nw,wl,xso3,0)

!     ... derive tauo3 for the three o2 srb
      do lev = 1, nz
	  do iw = 1, 4
          tauo3(lev,iw) = exp(-xso3_ms93(iw)*o3scol(lev))
	  end do
      end do
!----------------------------------------------------------------
!   	... call pjno function to derive sr band jno contributions
!         called in order of wavelength interval (shortest firs)
!----------------------------------------------------------------
      do lev = 1,nz
	 jno100   = pjno( 1, cs2100, wtno100, csno100 )
         jno90    = pjno( 2, cs290,  wtno90,  csno90 )
         jno50    = pjno( 4, cs250,  wtno50,  csno50 )
         jno(lev) = jno50 + jno90 + jno100
      end do

      contains

      real function pjno( w, cso2, wtno, csno )
!----------------------------------------------------------------
!   	... uses xsec at center of g subinterval for o2
!           uses mean values for no
!----------------------------------------------------------------
       implicit none

!----------------------------------------------------------------
!	... parameters
!----------------------------------------------------------------
      integer, parameter :: ngint = 6, nno = 2

!----------------------------------------------------------------
!	... dummy args
!----------------------------------------------------------------
      integer, intent(in) :: w
      real, intent(in) :: cso2(ngint)
      real, dimension(ngint,nno), intent(in) :: csno, wtno

!----------------------------------------------------------------
!	... local variables
!----------------------------------------------------------------
      integer ::  jj, i, k
      real :: tauno, transno, transo2, tauo2
      real :: jno, jno1
!----------------------------------------------------------------
!	... derive the photolysis frequency for no within a given
!         srb (i.e., 5-0, 9-0, 10-0)
!----------------------------------------------------------------
      jno = 0.
      
      do k = 1,ngint
	   tauo2 = o2scol(lev) * cso2(k) 
	 if( tauo2 < 50. ) then
	    transo2 = exp( -tauo2 )
	 else
	    transo2 = 0.
	 end if
         jno1 = 0.    
         do jj = 1,nno
             tauno = noscol(lev)*csno(k,jj)
	    if( tauno < 50. ) then
	       transno = exp( -tauno )
	    else
	       transno = 0.
	    end if

            jno1 = jno1 + csno(k,jj) * wtno(k,jj) * transno     
         end do
         jno = jno + jno1*transo2
      end do

      pjno = delta_wc_ms93(w)*etfphot_ms93(w)*tauo3(lev,w)*jno

!----------------------------------------------------------------
!	... correct for the predissociation of the deltq 1-0 
!         transition in the srb (5-0) 
!----------------------------------------------------------------
      if( w == 4 ) then
        pjno = 1.65e9/(5.1e7 + 1.65e9 + (1.5e-9*n2cc(lev)))*pjno
      end if 

      end function pjno
      
      end subroutine CALCJNO



