      SUBROUTINE nomas(
     $     nz,z,dsdh,nid,NOlev,NOscol)
!-----------------------------------------------------------------------------!
!   PURPOSE:                                                                  !
!   Calculate Nitric Oxide (NO) Slant Column                                  !
!-----------------------------------------------------------------------------!
!   PARAMETERS:                                                               !
!   DOBNEW - REAL, overhead ozone column amount (DU) to which profile     (I) !
!            should be scaled.  If DOBNEW < 0, no scaling is done             !
!   NZ     - INTEGER, number of specified altitude levels in the working  (I) !
!            grid                                                             !
!   Z      - REAL, specified altitude working grid (km)                   (I) !
!   DSDH   - REAL, slant path of direct beam through each layer crossed  (O)  !
!             when travelling from the top of the atmosphere to layer i;      !
!             DSDH(i,j), i = 0..NZ-1, j = 1..NZ-1                             !
!   NID    - INTEGER, number of layers crossed by the direct beam when   (O)  !
!             travelling from the top of the atmosphere to layer i;           !
!             NID(i), i = 0..NZ-1                                             !
!            specified altitude at each specified wavelength                  !
!   NOLEV  - REAL, Nitric Oxide concentration, molecules cm-3                 !
!   NOSCOL - REAL, Nitric Oxide Slant Column, molecules cm-2                  !
!-----------------------------------------------------------------------------!
!   EDIT HISTORY:                                                             !
!   09/01  Read in profile from an input file, DEK                            !
!-----------------------------------------------------------------------------!
!  This program is free software;  you can redistribute it and/or modify      !
!  it under the terms of the GNU General Public License as published by the   !
!  Free Software Foundation;  either version 2 of the license, or (at your    !
!  option) any later version.                                                 !
!  The TUV package is distributed in the hope that it will be useful, but     !
!  WITHOUT ANY WARRANTY;  without even the implied warranty of MERCHANTIBI-   !
!  LITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public      !
!  License for more details.                                                  !
!  To obtain a copy of the GNU General Public License, write to:              !
!  Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.    !
!-----------------------------------------------------------------------------!
!  To contact the authors, please mail to:                                    !
!  Sasha Madronich, NCAR/ACD, P.O.Box 3000, Boulder, CO, 80307-3000, USA  or  !
!  send email to:  sasha@ucar.edu                                             !
!-----------------------------------------------------------------------------!
!  Copyright (C) 1994,95,96  University Corporation for Atmospheric Research  !
!-----------------------------------------------------------------------------!
      implicit none
      include 'params'

!------------------------------------------------------------------------------
!     ... input: 
!------------------------------------------------------------------------------
      real, intent(in)    :: z(kz)
      integer, intent(in) :: nz
      real, intent(in)    :: nolev(kz)
      real, intent(in )   :: dsdh(0:kz,kz)
      integer, intent(in) :: nid(0:kz)

!------------------------------------------------------------------------------
!     ...  output:
!------------------------------------------------------------------------------
      real, intent(out)   :: noscol(kz)
!------------------------------------------------------------------------------
!     ... local:
!------------------------------------------------------------------------------
      real :: sum
      real :: ssum
      real :: vsum
      real :: deltaz
      real :: cz(nz)
      real :: hscale

      real :: vcol(nz)
      real :: scol(nz)

      integer :: id
      integer :: j
      integer :: i
!------------------------------------------------------------------------------
!     ... compute column increments (logarithmic integrals)
!------------------------------------------------------------------------------
      do i = 1, nz - 1
        deltaz = 1.e5 * (z(i+1)-z(i)) 
        cz(i) =(nolev(i+1)-nolev(i)) /alog(nolev(i+1)/nolev(i)) * deltaz
      end do

!------------------------------------------------------------------------------
!     ... Include exponential tail integral from infinity to 150 km,
!         fold tail integral into top layer
!         specify scale height near top of data.
!------------------------------------------------------------------------------
      hscale = 10.0e5 
      cz(nz-1) = cz(nz-1) + hscale * nolev(nz)

!------------------------------------------------------------------------------
!       ...  Calculate vertical and slant column from each level:
!            work downward
!------------------------------------------------------------------------------
      vsum = 0.
      ssum = 0.
      do id = 0, nz - 1
         vsum = vsum + cz(nz-id)
         vcol(nz-id) = vsum
         sum = 0.
         if(nid(id) .lt. 0) then
            sum = largest
         else

!------------------------------------------------------------------------------
!       ...  Single pass layers:
!------------------------------------------------------------------------------
            do j = 1, min(nid(id), id)
               sum = sum + cz(nz-j)*dsdh(id,j)
            enddo

!------------------------------------------------------------------------------
!       ...  Double pass layers:
!------------------------------------------------------------------------------

            do j = min(nid(id),id)+1, nid(id)
               sum = sum + 2.*cz(nz-j)*dsdh(id,j)
            enddo

         endif
         noscol(nz - id) = sum
       enddo

      end subroutine NOMAS
