      subroutine SETAIR(pmbnew,nz,z,nw,wl,airlev,dtrl,cz,pathname)
!-----------------------------------------------------------------------------!
!   PURPOSE:                                                                  !
!   Set up an altitude profile of air molecules.  Subroutine includes a       !
!   shape-conserving scaling method that allows scaling of the entire         !
!   profile to a given sea-level pressure.                                    !
!-----------------------------------------------------------------------------!
!   PARAMETERS:                                                               !
!   PMBNEW  - REAL, sea-level pressure (mb) to which profile should be    (I) !
!             scaled.  If PMBNEW < 0, no scaling is done                      !
!   NZ      - INTEGER, number of specified altitude levels in the working (I) !
!             grid                                                            !
!   Z       - REAL, specified altitude working grid (km)                  (I) !
!   NW      - INTEGER, number of specified intervals + 1 in working       (I) !
!             wavelength grid                                                 !
!   WL      - REAL, vector of lower limits of wavelength intervals in     (I) !
!             working wavelength grid                                         !
!   AIRLEV  - REAL, air density (molec/cc) at each specified altitude     (O) ! 
!   DTRL    - REAL, Rayleigh optical depth at each specified altitude     (O) !
!             and each specified wavelength                                   !
!   CZ      - REAL, number of air molecules per cm^2 at each specified    (O) !
!             altitude layer                                                  !
!-----------------------------------------------------------------------------!
!   EDIT HISTORY:                                                             !
!   02/97  Read in profile from an input file                                 !
!   01/18/02 Updated Style to Fortran 90, CCSM Standands, Doug Kinnison       !
!-----------------------------------------------------------------------------!
!  This program is free software;  you can redistribute it and/or modify      !
!  it under the terms of the GNU General Public License as published by the   !
!  Free Software Foundation;  either version 2 of the license, or (at your    !
!  option) any later version.                                                 !
!  The TUV package is distributed in the hope that it will be useful, but     !
!  WITHOUT ANY WARRANTY;  without even the implied warranty of MERCHANTIBI-   !
!  LITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public      !
!  License for more details.                                                  !
!  To obtain a copy of the GNU General Public License, write to:              !
!  Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.    !
!-----------------------------------------------------------------------------!
!  To contact the authors, please mail to:                                    !
!  Sasha Madronich, NCAR/ACD, P.O.Box 3000, Boulder, CO, 80307-3000, USA  or  !
!  send email to:  sasha@ucar.edu                                             !
!-----------------------------------------------------------------------------!
!  Copyright (C) 1994,95,96  University Corporation for Atmospheric Research  !
!-----------------------------------------------------------------------------!

      implicit none
      include 'params'

!------------------------------------------------------------------------------
!     ... input grids:
!------------------------------------------------------------------------------
      real, intent(in) :: wl(kw)
      real, intent(in) ::  z(kz)
      real, intent(in) :: pmbnew

      integer, intent(in) :: nw
      integer, intent(in) :: nz
      
      character*80 pathname
!------------------------------------------------------------------------------
!     ... output:
!------------------------------------------------------------------------------
      real, intent(out) :: airlev(kz)		! AD (molec cm-3) at each grid level
      real, intent(out) :: dtrl(kz,kw)	! rayleigh optical depths

!------------------------------------------------------------------------------
!     ... local:
!------------------------------------------------------------------------------
      real scale
      real airnew(kz)
      real colold
      real colnew
      real pmbold
      real pconv
      parameter(pconv = 980.665 * 1.e-3 * 28.9644 / 6.022169e23)

!     ... specified data
      real zd(kz)
      real air(kz)
      real hscale
      real cd(kz)

!     ... other
      real cz(kz)
      real srayl(kw)
      real deltaz
      real colz
      real pressz
      real wc
      real wmicrn
      real xx 

      integer iz, iw, nd, nskip
      
!------------------------------------------------------------------------------
!     ... external functions
!------------------------------------------------------------------------------
      real fsum
      external fsum

!------------------------------------------------------------------------------
!     ... read in air density profile
!------------------------------------------------------------------------------
      write(kout,*) 'Air Density Profile: WACCM'

      open(kin,file=
     $ TRIM(pathname)//'waccm_AD_photo_comb.mew',status='old')
	read(kin,*) nskip, nd
      do iz = 1, nskip
        read(kin,*)
      end do
	do iz = 1, nd
        read(kin,*) zd(iz), air(iz) 
	end do
      close(kin) 

!------------------------------------------------------------------------------
!     ... compute column increments (logarithmic integrals)
!------------------------------------------------------------------------------
      do iz = 1, nd - 1
         deltaz = 1.e5 * (zd(iz+1)-zd(iz)) 
         cd(iz)  = (air(iz+1)-air(iz)) /alog(air(iz+1)/air(iz)) * deltaz 
      end do

      hscale = 10.0e5 
      cd(nz-1) = cd(nz-1) + hscale * air(nz)
 
!------------------------------------------------------------------------------
!     ... if want, can rescale to any total pressure:
!------------------------------------------------------------------------------
      colold = fsum(nd-1,cd)
      pmbold = colold * pconv 
      write(kout,100) colold, pmbold

!     ... assign new sea level pressure

      if (pmbnew .lt. 0.) then
         scale = 1.
      else
         scale = pmbnew/pmbold
      endif

      do iz = 1, nd-1
         cd(iz) = cd(iz) * scale
         airnew(iz) = air(iz) * scale
      enddo
      airnew(nd) = air(nd) * scale
      
      colnew = fsum(nd-1,cd)
      write(kout,105) colnew, colnew * pconv
 
!------------------------------------------------------------------------------
!     ... compute air density at each level
!------------------------------------------------------------------------------
      nd = nd + 1
      call inter1(nz, z, airlev, nd, zd, airnew)

!------------------------------------------------------------------------------
!     ... compute column increments on standard z-grid.  
!------------------------------------------------------------------------------
      call inter3(nz,z,cz, nd, zd, cd, 1)

      colz   = fsum(nz-1,cz)
      pressz =  colz * pconv
      write(kout,110) colz, pressz

!------------------------------------------------------------------------------      
!     ... compute rayleigh cross sections and depths:
!------------------------------------------------------------------------------
      do iw = 1, nw - 1
         wc = (wl(iw) + wl(iw+1))/2.

!     ... rayleigh scattering cross section from wmo 1985 (originally from
!     ... Nicolet, m., on the molecular scattering in the terrestrial atmosphere:
!     ... an empirical formula for its calculation in the homoshpere, planet.
!     ... space sci., 32, 1467-1468, 1984.

         wmicrn =  wc / 1.e3
         if( wmicrn .le. 0.55) then
            xx = 3.6772 + 0.389*wmicrn + 0.09426/wmicrn
         else
            xx = 4. + 0.04
         endif
         srayl(iw) = 4.02e-28/(wmicrn)**xx

         do iz = 1, nz - 1
            dtrl(iz,iw) = cz(iz)*srayl(iw)
         end do
      end do

!------------------------------------------------------------------------------
!     ... format statements
!------------------------------------------------------------------------------
  100 format(5x,'old sea level air column = ', 1pe11.4,1x,'# cm-2  = ',
     $     0pf8.2,' mbar')
  105 format(5x,'new sea level air column = ', 1pe11.4,1x,'# cm-2  = ',
     $     0pf8.2,' mbar')
  110 format(5x,'surface air column = ', 1pe11.4,1x,'# cm-2  = ',
     $     0pf8.2,' mbar')


      end subroutine SETAIR
