      subroutine SETO3(dobnew,
     $     nz, z, nw, wl,
     $     tlay, xso3, dto3, o3den, o3vcol, dobson,
     $     pn, pn1)
!-----------------------------------------------------------------------------!
!   PURPOSE:                                                                  !
!   Set up an altitude profile of ozone, and corresponding absorption         !
!   optical depths.  Subroutine includes a shape-conserving scaling method    !
!   that allows scaling of the entire profile to a given overhead ozone       !
!   column amount.                                                            !
!-----------------------------------------------------------------------------!
!   PARAMETERS:                                                               !
!   DOBNEW - REAL, overhead ozone column amount (DU) to which profile     (I) !
!            should be scaled.  If DOBNEW < 0, no scaling is done             !
!   NZ     - INTEGER, number of specified altitude levels in the working  (I) !
!            grid                                                             !
!   Z      - REAL, specified altitude working grid (km)                   (I) !
!   NW     - INTEGER, number of specified intervals + 1 in working        (I) !
!            wavelength grid                                                  !
!   WL     - REAL, vector of lower limits of wavelength intervals in      (I) !
!            working wavelength grid                                          !
!   TLAY   - REAL, temperature (K) at each specified altitude layer       (I) !
!   DTO3   - REAL, optical depth due to ozone absorption at each          (O) !
!            specified altitude at each specified wavelength                  !
!-----------------------------------------------------------------------------!
!   EDIT HISTORY:                                                             !
!   02/97  Read in profile from an input file                                 !
!   01/18/02 Updated Style to Fortran 90, CCSM Standands, Doug Kinnison       !
!-----------------------------------------------------------------------------!
      IMPLICIT NONE
      INCLUDE 'params'

!------------------------------------------------------------------------------
!     ... input grids: 
!------------------------------------------------------------------------------
      real, intent(in) :: wl(kw)
      real, intent(in) :: z(kz)
      integer, intent (in) :: nw
      integer, intent (in) :: nz
      character*80 pn, pn1
!------------------------------------------------------------------------------
!     ... input ozone absorption cross sections at 226, 263, and 298 k:
!------------------------------------------------------------------------------
      real, intent(in) :: dobnew

!------------------------------------------------------------------------------
!     ... input mid-layer temperature:
!------------------------------------------------------------------------------
      real, intent(in) :: tlay(kz) 

!------------------------------------------------------------------------------
!     ... output:
!------------------------------------------------------------------------------
      real, intent(out) :: dto3  (kz,kw)
      real, intent(out) :: o3den (kz)
      real, intent(out) :: dobson
      real, intent(out) :: o3vcol(kz)
      real, intent(out) :: xso3  (kw)
!------------------------------------------------------------------------------
!     ... local:
!------------------------------------------------------------------------------
!     ... ozone profile data:
      real cz(kz)
      real zd(kz), o3(kz), cd(kz)
      real hscale, dobold, scale
      real colold, colnew, deltaz
      real to3(kz,nw)

!     ... Ozone XS data:
      integer, parameter :: kdata = 250
      integer iz, iw, nd, nskip
      integer n1, n2, n3, iskip, ierr
      integer i, n
      real x1    (kdata), x2   (kdata), x3(kdata)
      real y1    (kdata), y2   (kdata), y3(kdata)
      real so3   (kz,kw)
      real yg298(kw), yg218(kw),  yg(kw)
      real a1, a2, a3

!------------------------------------------------------------------------------
!     ... external functions:
!------------------------------------------------------------------------------
      real fsum
      external fsum

!------------------------------------------------------------------------------
!     ... read in ozone profile
!------------------------------------------------------------------------------
      write(kout,*) 'Ozone Profile: WACCM'

      open(kin,file=
     & TRIM(pn)//'waccm_O3_photo_comb.mew',status='old')
	read(kin,*) nskip, nd
      do iz = 1, nskip
        read(kin,*)
      end do
	do iz = 1, nd
        read(kin,*) zd(iz), o3(iz) 
	end do
      close(kin) 

!------------------------------------------------------------------------------
!     ... added from o3mas, dek (log approach)
!------------------------------------------------------------------------------
      do iz = 1, nz - 1
        deltaz = 1.e5 * (zd(iz+1)-zd(iz)) 
        cd(iz) =(o3(iz+1)-o3(iz)) /alog(o3(iz+1)/o3(iz)) * deltaz
!
! jfl
!
        cd(iz) =0.5 * (o3(iz+1)+o3(iz)) * deltaz

      end do

      hscale = 10.0e5
      cd(nd-1)   = cd(nd-1) + hscale * o3(nd)

!------------------------------------------------------------------------------
!     ... compute ozone concentration on standard z-grid
!------------------------------------------------------------------------------
!     ... need to add nz+1 to get the top o3 value.
      nd = nd +1
      call inter1(nz, z, o3den, nd, zd, o3)
   
!------------------------------------------------------------------------------
!     ... compute column increments on standard z-grid.  
!------------------------------------------------------------------------------
      call inter3(nz, z, cz, nd, zd, cd, 1)

!------------------------------------------------------------------------------
!     ... scale values of cz(i) by any dobson unit
!------------------------------------------------------------------------------
      colold = fsum(nz-1,cz)
      dobold = colold / 2.687e16
      write(kout,100) colold, dobold
      
      if (dobnew .lt. 0.) then
         scale = 1.0
      else

         scale = dobnew/dobold

      endif
      do iz = 1, nz-1
         cz(iz) = cz(iz) * scale
      enddo
      colnew = fsum(nz-1,cz)

!------------------------------------------------------------------------------
!     ... scale and calculate column
!------------------------------------------------------------------------------
   
      do iz = nz-1, 1, -1
         o3vcol(iz) = cz(iz) + o3vcol(iz+1)
      enddo

      write(kout,105) colnew, colnew/2.687e16
      dobson = colnew/2.687e16
!------------------------------------------------------------------------------
!     ... calculate ozone optical depth for each layer, with temperature
!     ... correction.  output, dto3(kz,kw)
!------------------------------------------------------------------------------
!-----------------------------------------------------------
!     Ref: Atkinson, ultraviolet solar radiation related to 
!          mesopheric procesess, 149-159, in fiocco, g. (ed.), 
!          mesospheric models and related exp., d. reidel, 
!          dordrecht, 1971. 
!
!          120 nm through 200 nm
!-----------------------------------------------------------
      open(unit=kin,file=TRIM(pn1)//'XS_O3_Ackerman_1971.txt',
     $     status='old')
      read(kin,*) iskip, n
      do i = 1, iskip
        read(kin,*) 
      end do
      do i = 1, n
        read(kin,*) x1(i), y1(i)
      enddo
      close(kin)

      call addpnt(x1,y1,kdata,n,x1(1)*(1.-deltax),0.)
      call addpnt(x1,y1,kdata,n,               0.,0.)
      call addpnt(x1,y1,kdata,n,x1(n)*(1.+deltax),0.)
      call addpnt(x1,y1,kdata,n,           1.e+38,0.)
      call inter2(nw,wl,yg,n,x1,y1,ierr)

      do iw = 1, nw-1
         xso3(iw) = yg(iw)
      enddo

!-------------------------------------------------------
!     ... REF: JPL06 218K
!         from 196.078 to 342.5 nm
!-------------------------------------------------------
      open(unit=kin,file=TRIM(pn1)//'XS_O3_218_JPL06.txt',
     $     status='old')
      read(kin,*) iskip, n
      do i = 1, iskip
        read(kin,*) 
      end do
      do i = 1, n
        read(kin,*) a1, a2, y2(i)
        x2(i) = (a1+a2)/2.
!        print*, x2(i), y2(i)
      enddo
      close(kin)

      call addpnt(x2,y2,kdata,n,x2(1)*(1.-deltax),0.)
      call addpnt(x2,y2,kdata,n,               0.,0.)
      call addpnt(x2,y2,kdata,n,x2(n)*(1.+deltax),0.)
      call addpnt(x2,y2,kdata,n,           1.e+38,0.)
      call inter2(nw,wl,yg218,n,x2,y2,ierr)

!-------------------------------------------------------
!     ... REF: JPL06 293-298K
!         from 185.185 to 827.500 nm
!-------------------------------------------------------
      open(unit=kin,file=TRIM(pn1)//'XS_O3_298_JPL06.txt',
     $     status='old')
      read(kin,*) iskip, n
      do i = 1, iskip
        read(kin,*) 
      end do
      do i = 1, n
        read(kin,*) a1, a2, y3(i)
        x3(i) = (a1+a2)/2.
      enddo
      close(kin)

      call addpnt(x3,y3,kdata,n,x3(1)*(1.-deltax),0.)
      call addpnt(x3,y3,kdata,n,               0.,0.)
      call addpnt(x3,y3,kdata,n,x3(n)*(1.+deltax),0.)
      call addpnt(x3,y3,kdata,n,           1.e+38,0.)
      call inter2(nw,wl,yg298,n,x3,y3,ierr)

      do iw = 1, nw-1
	if (wl(iw) .ge. 184.0) then
           xso3(iw) = yg298(iw)
	endif
      enddo

!-------------------------------------------------------
!     ... for hartley and huggins bands, use 
!         temperature-dependent values from
!         JPL06
!-------------------------------------------------------
!-------------------------------------------------------
!     ... Cross Sections and Quantum Yields
!-------------------------------------------------------
      do iw = 1, nw-1
         do iz = 1, nz-1

           so3(iz,iw) = xso3(iw)

           if ((wl(iw) .ge. 196.078) .and. (wl(iw) .le. 342.5)) then

             if (tlay(iz) .lt. 218.) then
               so3(iz,iw) = yg218(iw)
             endif
             if ((tlay(iz) .ge. 218.) .and. (tlay(iz) .le. 298.)) then
               so3(iz,iw) = yg218(iw)+(yg298(iw)-yg218(iw))/(298.-218.)*
     $                 (tlay(iz)-218.)
             endif
             if (tlay(iz) .gt. 298.) then
               so3(iz,iw) = yg298(iw)
             endif
           endif

           dto3(iz,iw) = cz(iz)*so3(iz,iw)

          enddo
       enddo
       
!       do iz = 50,151
!         do iw = 3, 3
!           print*, wl(iw), iz, so3(iz,iw), cz(iz), dto3(iz,iw)
!         enddo
!       enddo
       
!------------------------------------------------------------------------------
!     ... Format Statements
!------------------------------------------------------------------------------
  100 format(5x,'old o3 column = ', 1pe11.4,1x,'# cm-2  = ',
     $     0pf8.2, '  dobson units ')
  105 format(5x,'new o3 column = ', 1pe11.4,1x,'# cm-2  = ',
     $     0pf8.2, '  dobson units ')

      end subroutine SETO3
