       SUBROUTINE sjo2(nz,nw,wc,xso2,nj,sq)

!-----------------------------------------------------------------------------!
!   PURPOSE:                                                                  !
!   Update the weighting function (cross section x quantum yield) for O2      !
!   photolysis.  Effective O2 cross section depends upon solar zenith angle   !
!   (Schuman-Runge bands), so needs to be update at each time step.           !
!
!   Branch 1: O2 + hv -> O(1D) + O(3P), 120-175.9 nm, QY = Marsh Thesis, 1999 !
!                                                                             !
!   Branch 2: O2 + hv -> O(3P) + O(3P), 175.9-242 nm, QY = 1                  !
!                                                                             !
!-----------------------------------------------------------------------------!
!   PARAMETERS:                                                               !
!   NZ     - INTEGER, number of altitude levels in working altitude grid  (I) !
!   NW     - INTEGER, number of specified intervals + 1 in working        (I) 
!            wavelength grid                                                  !
!   XSO2   - REAL, molecular absorption cross section in SR bands at      (I) !
!            each specified altitude and wavelength.  Includes Herzberg       !
!             continuum.                                                      !
!   NJ     - INTEGER, index of O2 photolysis in array SQ                  (I) !
!   SQ     - REAL, cross section x quantum yield (cm^2) for each          (O) !
!            photolysis reaction defined, at each defined wavelength and      !
!            at each defined altitude level                                   !
!-----------------------------------------------------------------------------!
!   EDIT HISTORY:                                                             !
!   08/96  Original                                                           !
!   06/01  Modified by Doug Kinnison to add addition O2+ hv -> O(3P) + O(1D)  !
!-----------------------------------------------------------------------------!
      implicit none
      include 'params'

!-----------------------------------------------------------------------------
!     ... INPUT
!-----------------------------------------------------------------------------
      integer, intent(in) :: nz
      integer, intent(in) :: nw
      integer, intent(in) :: nj

      real, intent(in) :: xso2(kz,kw)
      real, intent(in) :: wc(kw)
!-----------------------------------------------------------------------------
!     ... OUTPUT
!-----------------------------------------------------------------------------
      real, intent(inout) :: sq(kj,kz,kw)

!-----------------------------------------------------------------------------
!     ... LOCAL
!-----------------------------------------------------------------------------
      integer iw, iz
      real qy1, qy2

!-----------------------------------------------------------------------------
!     ... Shortward of 174.65 the product is O2 + hv => O(3P) + O(1D)
!     ... Longward  of 174.65 the product is O2 + hv => O(3P) + O(3P)
! 
!     ... The QY is assumed to be unity in both wavelength ranges.
!
!     ... O2 + hv -> O(3P) + O(3P)
!     ....assign cross section values at all wavelengths and at all altitudes
!-----------------------------------------------------------------------------
      qy1 = 1.
      qy2 = 1.

      do iw = 1, nw-1

        if (wc(iw) .gt. 174.65) then
          do iz = 1, nz
            sq(nj+1,iz,iw) = xso2(iz,iw)*qy2
          enddo
	else
          do iz = 1, nz
            sq(nj+1,iz,iw) = 0.0
          enddo
        endif
!-----------------------------------------------------------------------------
!     ... o2 + hv -> o(3p) + o(1d)
!         assign cross section values at all wavelengths and at all altitudes
!-----------------------------------------------------------------------------
        if (wc(iw) .ge. 174.65) then
          do iz = 1, nz
            sq(nj,iz,iw) = 0.0
          enddo
	else
          do iz = 1, nz
            sq(nj,iz,iw) = xso2(iz,iw)*qy1
          enddo
        endif

      enddo 
!-----------------------------------------------------------------------------
!     ... o2 + hv -> o(3p) + o(1d) at lyman alpha has a qy = 0.53
!         Lacoursiere et al., J. Chem. Phys. 110., 1949-1958, 1999.
!         iw = 2 is lyman alpha (121.65nm)
!-----------------------------------------------------------------------------
      do iz = 1, nz
         sq(nj,iz,2)     = xso2(iz,2)*0.53
      enddo

      do iz = 1, nz
         sq(nj+1,iz,2)   = xso2(iz,2)*0.47
      enddo
      
!      do iz=110,110
!       do iw = 1,34
!         print*,iz,wc(iw), sq(nj+1,iz,iw),sq(nj+1,iz+10,iw)
!       enddo
!      enddo
!      stop

      end subroutine SJO2
